# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: scalekit/v1/connections/connections.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from protoc_gen_openapiv2.options import annotations_pb2 as protoc__gen__openapiv2_dot_options_dot_annotations__pb2
from scalekit.v1.commons import commons_pb2 as scalekit_dot_v1_dot_commons_dot_commons__pb2
from scalekit.v1.domains import domains_pb2 as scalekit_dot_v1_dot_domains_dot_domains__pb2
from scalekit.v1.options import options_pb2 as scalekit_dot_v1_dot_options_dot_options__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)scalekit/v1/connections/connections.proto\x12\x17scalekit.v1.connections\x1a\x1b\x62uf/validate/validate.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1bgoogle/api/visibility.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a.protoc-gen-openapiv2/options/annotations.proto\x1a!scalekit/v1/commons/commons.proto\x1a!scalekit/v1/domains/domains.proto\x1a!scalekit/v1/options/options.proto\"\xc4\x01\n AssignDomainsToConnectionRequest\x12;\n\x0forganization_id\x18\x01 \x01(\tB\x12\xbaH\x0fr\n\x10\x01\x18 :\x04org_\xc8\x01\x01R\x0eorganizationId\x12\x38\n\rconnection_id\x18\x02 \x01(\tB\x13\xbaH\x10r\x0b\x10\x01\x18 :\x05\x63onn_\xc8\x01\x01R\x0c\x63onnectionId\x12)\n\ndomain_ids\x18\x03 \x03(\tB\n\xbaH\x07\x92\x01\x04\x08\x00\x10\x32R\tdomainIds\"\xe6\x03\n!AssignDomainsToConnectionResponse\x12\xc0\x03\n\nconnection\x18\x01 \x01(\x0b\x32#.scalekit.v1.connections.ConnectionB\xfa\x02\x92\x41\xf6\x02\x32 Connection with assigned domainsJ\xd1\x02{\n  \"id\": \"conn_1234567890\",\n  \"provider\": \"OKTA\",\n  \"type\": \"OIDC\",\n  \"status\": \"CONFIGURED\",\n  \"enabled\": true,\n  \"debug_enabled\": false,\n  \"organization_id\": \"org_1234567890\",\n  \"ui_button_title\": \"Login with SSO\",\n  \"configuration_type\": \"MANUAL\",\n  \"test_connection_uri\": \"https://auth.example.com/test-connection/conn_1234567890\"\n}R\nconnection\"\x15\n\x13GetProvidersRequest\"W\n\x14GetProvidersResponse\x12?\n\tproviders\x18\x01 \x03(\x0b\x32!.scalekit.v1.connections.ProviderR\tproviders\"\xf3\x01\n\x08Provider\x12\x35\n\x06key_id\x18\x01 \x01(\tB\x1e\x92\x41\x1b\x32\x0fProvider Key IDJ\x08\"google\"R\x05keyId\x12G\n\x0c\x64isplay_name\x18\x02 \x01(\tB$\x92\x41!2\x15Provider Display NameJ\x08\"Google\"R\x0b\x64isplayName\x12W\n\x0b\x64\x65scription\x18\x03 \x01(\tB0\x92\x41-2\x14Provider DescriptionJ\x15\"Sign In With Google\"H\x00R\x0b\x64\x65scription\x88\x01\x01\x42\x0e\n\x0c_description\"\xae\x02\n\"CreateEnvironmentConnectionRequest\x12Q\n\nconnection\x18\x01 \x01(\x0b\x32).scalekit.v1.connections.CreateConnectionB\x06\xbaH\x03\xc8\x01\x01R\nconnection\x12\xaa\x01\n\x05\x66lags\x18\x02 \x01(\x0b\x32\x1e.scalekit.v1.connections.FlagsBo\x92\x41l2SOptional flags to control connection creation behavior, such as enabling debug modeJ\x15{ \"is_social\": true }H\x00R\x05\x66lags\x88\x01\x01\x42\x08\n\x06_flags\"\x8f\x02\n\x17\x43reateConnectionRequest\x12\x9a\x01\n\x0forganization_id\x18\x01 \x01(\tBq\x92\x41\x65\x32JUnique identifier of the organization for which the connection is created.J\x17\"org_12362474900684814\"\xbaH\x06r\x04\x10\x01\x18 R\x0eorganizationId\x12Q\n\nconnection\x18\x03 \x01(\x0b\x32).scalekit.v1.connections.CreateConnectionB\x06\xbaH\x03\xc8\x01\x01R\nconnectionJ\x04\x08\x02\x10\x03\"\xe9\x03\n\x10\x43reateConnection\x12\xcb\x01\n\x08provider\x18\x01 \x01(\x0e\x32+.scalekit.v1.connections.ConnectionProviderB\x81\x01\x92\x41v2lIdentity provider service that handles authentication (such as OKTA, Google, Azure AD, or a custom provider)J\x06\"OKTA\"\xbaH\x05\x82\x01\x02\x10\x01R\x08provider\x12\x45\n\x04type\x18\x02 \x01(\x0e\x32\'.scalekit.v1.connections.ConnectionTypeB\x08\xbaH\x05\x82\x01\x02\x10\x01R\x04type\x12\x98\x01\n\x0cprovider_key\x18\x03 \x01(\tBu\x92\x41r2fKey ID of the identity provider. This is used to identify the specific configuration for the provider.J\x08\"google\"R\x0bproviderKey\x12\x1a\n\x06key_id\x18\x04 \x01(\tH\x00R\x05keyId\x88\x01\x01\x42\t\n\x07_key_id\"\x97\x1f\n\nConnection\x12\x8d\x01\n\x02id\x18\x01 \x01(\tB}\x92\x41z2_Unique identifier for this connection. Used in API calls to reference this specific connection.J\x17\"conn_2123312131125533\"R\x02id\x12\xc2\x01\n\x08provider\x18\x02 \x01(\x0e\x32+.scalekit.v1.connections.ConnectionProviderBy\x92\x41v2lIdentity provider service that handles authentication (such as OKTA, Google, Azure AD, or a custom provider)J\x06\"OKTA\"R\x08provider\x12\xb4\x01\n\x04type\x18\x03 \x01(\x0e\x32\'.scalekit.v1.connections.ConnectionTypeBw\x92\x41t2jAuthentication protocol used by this connection. Can be OIDC (OpenID Connect), SAML, OAUTH, or MAGIC_LINK.J\x06\"OIDC\"R\x04type\x12\xc6\x01\n\x06status\x18\x04 \x01(\x0e\x32).scalekit.v1.connections.ConnectionStatusB\x82\x01\x92\x41|2kCurrent configuration status of the connection. Possible values include IN_PROGRESS, CONFIGURED, and ERROR.J\r\"IN_PROGRESS\"\xe0\x41\x03R\x06status\x12\xab\x01\n\x07\x65nabled\x18\x05 \x01(\x08\x42\x90\x01\x92\x41\x8c\x01\x32\x82\x01\x43ontrols whether users can sign in using this connection. When false, the connection exists but cannot be used for authentication.J\x05\x66\x61lseR\x07\x65nabled\x12\xb0\x01\n\rdebug_enabled\x18\x06 \x01(\x08\x42\x8a\x01\x92\x41\x86\x01\x32~Enables testing mode that allows non-HTTPS endpoints. Should only be enabled in development environments, never in production.J\x04trueR\x0c\x64\x65\x62ugEnabled\x12\xc1\x01\n\x0forganization_id\x18\x07 \x01(\tB\x92\x01\x92\x41\x8e\x01\x32tIdentifier of the organization that owns this connection. Connections are typically scoped to a single organization.J\x16\"org_2123312131125533\"H\x01R\x0eorganizationId\x88\x01\x01\x12\xbd\x01\n\x0fui_button_title\x18\x08 \x01(\tB\x94\x01\x92\x41\x81\x01\x32mCustom text shown on the login button in the user interface. Helps users identify which SSO option to select.J\x10\"Login with SSO\"\xfa\xd2\xe4\x93\x02\t\x12\x07PREVIEWR\ruiButtonTitle\x12\xd5\x01\n\x12\x63onfiguration_type\x18\t \x01(\x0e\x32*.scalekit.v1.connections.ConfigurationTypeBz\x92\x41w2kHow the connection was configured: DISCOVERY (automatic configuration) or MANUAL (administrator configured)J\x08\"MANUAL\"R\x11\x63onfigurationType\x12\xdf\x01\n\x13test_connection_uri\x18\x0c \x01(\tB\xae\x01\x92\x41\xaa\x01\x32\x66URI that can be used to test this connection. Visit this URL to verify the connection works correctly.J@\"https://auth.example.com/test-connection/conn_2123312131125533\"R\x11testConnectionUri\x12\x81\x02\n\x11\x61ttribute_mapping\x18\x0f \x03(\x0b\x32\x39.scalekit.v1.connections.Connection.AttributeMappingEntryB\x98\x01\x92\x41|2zMaps identity provider attributes to user profile fields. For example, {\'email\': \'user.mail\', \'name\': \'user.displayName\'}.\xbaH\x16\x9a\x01\x13\x10\x1e\"\x06r\x04\x10\x01\x18\x64*\x07r\x05\x10\x01\x18\x80\x02R\x10\x61ttributeMapping\x12\xb1\x01\n\x0b\x63reate_time\x18\x10 \x01(\x0b\x32\x1a.google.protobuf.TimestampBt\x92\x41_2EWhen this connection was first created. Format is RFC 3339 timestamp.J\x16\"2023-01-15T14:30:00Z\"\xe0\x41\x03\xfa\xd2\xe4\x93\x02\t\x12\x07PREVIEWR\ncreateTime\x12\xb1\x01\n\x0bupdate_time\x18\x11 \x01(\x0b\x32\x1a.google.protobuf.TimestampBt\x92\x41_2EWhen this connection was last modified. Format is RFC 3339 timestamp.J\x16\"2023-02-20T09:15:30Z\"\xe0\x41\x03\xfa\xd2\xe4\x93\x02\t\x12\x07PREVIEWR\nupdateTime\x12\xb3\x01\n\x0boidc_config\x18\x12 \x01(\x0b\x32-.scalekit.v1.connections.OIDCConnectionConfigBa\x92\x41^2\\Configuration details for OpenID Connect (OIDC) connections. Present only when type is OIDC.H\x00R\noidcConfig\x12\xaa\x01\n\x0bsaml_config\x18\x13 \x01(\x0b\x32\x35.scalekit.v1.connections.SAMLConnectionConfigResponseBP\x92\x41M2KConfiguration details for SAML connections. Present only when type is SAML.H\x00R\nsamlConfig\x12\xa7\x01\n\x0coauth_config\x18\x14 \x01(\x0b\x32..scalekit.v1.connections.OAuthConnectionConfigBR\x92\x41O2MConfiguration details for OAuth connections. Present only when type is OAUTH.H\x00R\x0boauthConfig\x12\xbf\x01\n\x13passwordless_config\x18\x16 \x01(\x0b\x32+.scalekit.v1.connections.PasswordLessConfigB_\x92\x41\\2ZConfiguration details for Magic Link authentication. Present only when type is MAGIC_LINK.H\x00R\x12passwordlessConfig\x12\xc0\x01\n\rstatic_config\x18\x1a \x01(\x0b\x32).scalekit.v1.connections.StaticAuthConfigBn\x92\x41k2iStatic configuration for custom connections. Present only when type is BASIC, BEARER, API_KEY, or custom.H\x00R\x0cstaticConfig\x12}\n\x06key_id\x18\x19 \x01(\tBa\x92\x41^2\\Alternative identifier for this connection, typically used in frontend applications or URLs.H\x02R\x05keyId\x88\x01\x01\x12u\n\x0cprovider_key\x18\x17 \x01(\tBR\x92\x41O2CKey ID of the identity provider service that handles authenticationJ\x08\"google\"R\x0bproviderKey\x12\xaa\x01\n\x07\x64omains\x18\x18 \x03(\x0b\x32\x1b.scalekit.v1.domains.DomainBs\x92\x41p2SDomain associated with this connection, used for domain-based authentication flows.J\x19[{\"name\": \"example.com\"}]R\x07\x64omains\x1a\x43\n\x15\x41ttributeMappingEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\n\n\x08settingsB\x12\n\x10_organization_idB\t\n\x07_key_idJ\x04\x08\r\x10\x0f\"w\n\x18\x43reateConnectionResponse\x12[\n\nconnection\x18\x01 \x01(\x0b\x32#.scalekit.v1.connections.ConnectionB\x16\x92\x41\x13\x32\x11\x43onnection DetailR\nconnection\"\xa8\x02\n\"UpdateEnvironmentConnectionRequest\x12~\n\rconnection_id\x18\x01 \x01(\tBY\x92\x41M2+Connection ID. Unique ID for the connectionJ\x16\"conn_121312434123312\"\xca>\x05\xfa\x02\x02id\xbaH\x06r\x04\x10\x01\x18 R\x0c\x63onnectionId\x12\x81\x01\n\nconnection\x18\x03 \x01(\x0b\x32).scalekit.v1.connections.UpdateConnectionB6\x92\x41-2#Connection properties to be updated\xca>\x05\xfa\x02\x02id\xbaH\x03\xc8\x01\x01R\nconnection\"\xf9\x02\n\x17UpdateConnectionRequest\x12q\n\x0forganization_id\x18\x01 \x01(\tBH\x92\x41<2#Organization ID for the Connection.J\x15\"org_121312434123312\"\xbaH\x06r\x04\x10\x01\x18 R\x0eorganizationId\x12\x61\n\x02id\x18\x03 \x01(\tBQ\x92\x41\x45\x32+Connection ID. Unique ID for the connectionJ\x16\"conn_121312434123312\"\xbaH\x06r\x04\x10\x01\x18 R\x02id\x12\x81\x01\n\nconnection\x18\x04 \x01(\x0b\x32).scalekit.v1.connections.UpdateConnectionB6\x92\x41-2#Connection properties to be updated\xca>\x05\xfa\x02\x02id\xbaH\x03\xc8\x01\x01R\nconnectionJ\x04\x08\x02\x10\x03\"\x88\x0e\n\x10UpdateConnection\x12w\n\x08provider\x18\x02 \x01(\x0e\x32+.scalekit.v1.connections.ConnectionProviderB.\x92\x41#2\x17SSO Connection ProviderJ\x08\"CUSTOM\"\xbaH\x05\x82\x01\x02\x10\x01R\x08provider\x12r\n\x04type\x18\x03 \x01(\x0e\x32\'.scalekit.v1.connections.ConnectionTypeB5\x92\x41*2 Connection Protocol OIDC / SAML J\x06\"OIDC\"\xbaH\x05\x82\x01\x02\x10\x01R\x04type\x12\xae\x01\n\rdebug_enabled\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValueBm\x92\x41j2bDebug mode for the connection. Debug would allow non HTTPS endpoint to be used with the connectionJ\x04trueR\x0c\x64\x65\x62ugEnabled\x12\x8d\x01\n\x0fui_button_title\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValueBG\x92\x41\x35\x32!Display name for the Login ButtonJ\x10\"Login with SSO\"\xfa\xd2\xe4\x93\x02\t\x12\x07PREVIEWR\ruiButtonTitle\x12~\n\x12\x63onfiguration_type\x18\x0b \x01(\x0e\x32*.scalekit.v1.connections.ConfigurationTypeB#\x92\x41 2\x14\x43onfiguration Type. J\x08\"MANUAL\"R\x11\x63onfigurationType\x12\x9d\x01\n\x11\x61ttribute_mapping\x18\x0f \x03(\x0b\x32?.scalekit.v1.connections.UpdateConnection.AttributeMappingEntryB/\x92\x41\x13\x32\x11\x41ttribute Mapping\xbaH\x16\x9a\x01\x13\x10\x1e\"\x06r\x04\x10\x01\x18\x64*\x07r\x05\x10\x01\x18\x80\x02R\x10\x61ttributeMapping\x12\x83\x01\n\x0boidc_config\x18\x10 \x01(\x0b\x32-.scalekit.v1.connections.OIDCConnectionConfigB1\x92\x41.2,OIDC Configuration if ConnectionType == OIDCH\x00R\noidcConfig\x12\x8a\x01\n\x0bsaml_config\x18\x11 \x01(\x0b\x32\x34.scalekit.v1.connections.SAMLConnectionConfigRequestB1\x92\x41.2,SAML Configuration if ConnectionType == SAMLH\x00R\nsamlConfig\x12\x88\x01\n\x0coauth_config\x18\x12 \x01(\x0b\x32..scalekit.v1.connections.OAuthConnectionConfigB3\x92\x41\x30\x32.OAuth Configuration if ConnectionType == OAUTHH\x00R\x0boauthConfig\x12\x9d\x01\n\x13passwordless_config\x18\x14 \x01(\x0b\x32+.scalekit.v1.connections.PasswordLessConfigB=\x92\x41:28Magic Link Configuration if ConnectionType == MAGIC_LINKH\x00R\x12passwordlessConfig\x12P\n\rstatic_config\x18\x17 \x01(\x0b\x32).scalekit.v1.connections.StaticAuthConfigH\x00R\x0cstaticConfig\x12%\n\x06key_id\x18\x16 \x01(\tB\t\xbaH\x06r\x04\x10\x01\x18 H\x01R\x05keyId\x88\x01\x01\x12u\n\x0cprovider_key\x18\x15 \x01(\tBR\x92\x41O2CKey ID of the identity provider service that handles authenticationJ\x08\"google\"R\x0bproviderKey\x1a\x43\n\x15\x41ttributeMappingEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\n\n\x08settingsB\t\n\x07_key_idJ\x04\x08\x01\x10\x02J\x04\x08\x04\x10\x05J\x04\x08\x05\x10\x06J\x04\x08\t\x10\x0bJ\x04\x08\x0c\x10\x0f\"\x80\x01\n\x18UpdateConnectionResponse\x12\x64\n\nconnection\x18\x01 \x01(\x0b\x32#.scalekit.v1.connections.ConnectionB\x1f\x92\x41\x1c\x32\x1aUpdated Connection detailsR\nconnection\"\x9c\x01\n\"DeleteEnvironmentConnectionRequest\x12v\n\rconnection_id\x18\x03 \x01(\tBQ\x92\x41\x45\x32+Connection ID. Unique ID for the connectionJ\x16\"conn_121312434123312\"\xbaH\x06r\x04\x10\x01\x18 R\x0c\x63onnectionId\"\xf5\x01\n\x17\x44\x65leteConnectionRequest\x12q\n\x0forganization_id\x18\x01 \x01(\tBH\x92\x41<2#Organization ID for the Connection.J\x15\"org_121312434123312\"\xbaH\x06r\x04\x10\x01\x18 R\x0eorganizationId\x12\x61\n\x02id\x18\x03 \x01(\tBQ\x92\x41\x45\x32+Connection ID. Unique ID for the connectionJ\x16\"conn_121312434123312\"\xbaH\x06r\x04\x10\x01\x18 R\x02idJ\x04\x08\x02\x10\x03\"\x92\x01\n\x1fGetEnvironmentConnectionRequest\x12o\n\rconnection_id\x18\x01 \x01(\tBJ\x92\x41>2$Unique identifier for the ConnectionJ\x16\"conn_121312434123312\"\xbaH\x06r\x04\x10\x01\x18 R\x0c\x63onnectionId\"\xfc\x02\n\x14GetConnectionRequest\x12\xba\x01\n\x0forganization_id\x18\x01 \x01(\tB\x90\x01\x92\x41\x83\x01\x32jOrganization identifier (required). Specifies which organization owns the connection you want to retrieve.J\x15\"org_121312434123312\"\xbaH\x06r\x04\x10\x01\x18 R\x0eorganizationId\x12\xa0\x01\n\x02id\x18\x03 \x01(\tB\x8f\x01\x92\x41\x82\x01\x32hConnection identifier (required). Specifies which specific connection to retrieve from the organization.J\x16\"conn_121312434123312\"\xbaH\x06r\x04\x10\x01\x18 R\x02idJ\x04\x08\x02\x10\x03\"\x9a\x02\n\x15GetConnectionResponse\x12\x80\x02\n\nconnection\x18\x01 \x01(\x0b\x32#.scalekit.v1.connections.ConnectionB\xba\x01\x92\x41\xb6\x01\x32\xb3\x01\x43omplete connection details including provider configuration, protocol settings, status, and all metadata. Contains everything needed to understand the connection\'s current state.R\nconnection\"\x96\x04\n\x16ListConnectionsRequest\x12\x80\x01\n\x0forganization_id\x18\x01 \x01(\tBR\x92\x41\x46\x32-Filter connections by organization identifierJ\x15\"org_121312434123312\"\xbaH\x06r\x04\x10\x01\x18 H\x00R\x0eorganizationId\x88\x01\x01\x12\x7f\n\x06\x64omain\x18\x03 \x01(\tBb\x92\x41V2CFilter connections by email domain associated with the organizationJ\x0f\"hero-saas.app\"\xbaH\x06r\x04\x10\x01\x18 H\x01R\x06\x64omain\x88\x01\x01\x12\xc6\x01\n\x07include\x18\x04 \x01(\tB\xa6\x01\x92\x41\xa2\x01\x32\x9f\x01\x46ilter connections by status. Use \'all\' to include all connections regardless of status. Default behavior shows only active (completed and enabled) connectionsH\x02R\x07include\x88\x01\x01\x42\x12\n\x10_organization_idB\t\n\x07_domainB\n\n\x08_includeJ\x04\x08\x02\x10\x03\"\x9d\x01\n\x17ListConnectionsResponse\x12\x81\x01\n\x0b\x63onnections\x18\x01 \x03(\x0b\x32\'.scalekit.v1.connections.ListConnectionB6\x92\x41\x33\x32\x31List of connections matching the request criteriaR\x0b\x63onnections\"\xfa\x0b\n\x0eListConnection\x12Q\n\x02id\x18\x01 \x01(\tBA\x92\x41>2#Unique identifier of the connectionJ\x17\"conn_2123312131125533\"R\x02id\x12\x8d\x01\n\x08provider\x18\x02 \x01(\x0e\x32+.scalekit.v1.connections.ConnectionProviderBD\x92\x41\x41\x32\x35Identity provider type (e.g., OKTA, Google, Azure AD)J\x08\"CUSTOM\"R\x08provider\x12x\n\x04type\x18\x03 \x01(\x0e\x32\'.scalekit.v1.connections.ConnectionTypeB;\x92\x41\x38\x32.Authentication protocol used by the connectionJ\x06\"OIDC\"R\x04type\x12\x88\x01\n\x06status\x18\x04 \x01(\x0e\x32).scalekit.v1.connections.ConnectionStatusBE\x92\x41?2.Current configuration status of the connectionJ\r\"IN_PROGRESS\"\xe0\x41\x03R\x06status\x12g\n\x07\x65nabled\x18\x05 \x01(\x08\x42M\x92\x41J2AWhether the connection is currently active for organization usersJ\x05\x66\x61lseR\x07\x65nabled\x12\x85\x01\n\x0forganization_id\x18\x06 \x01(\tB\\\x92\x41Y2?Unique identifier of the organization that owns this connectionJ\x16\"org_2123312131125533\"R\x0eorganizationId\x12\x88\x01\n\x0fui_button_title\x18\x07 \x01(\tB`\x92\x41N2:Text displayed on the SSO login button for this connectionJ\x10\"Login with SSO\"\xfa\xd2\xe4\x93\x02\t\x12\x07PREVIEWR\ruiButtonTitle\x12t\n\x07\x64omains\x18\x08 \x03(\tBZ\x92\x41W2/List of domains configured with this connectionJ$[\"yourapp.com\", \"yourworkspace.com\"]R\x07\x64omains\x12q\n\x11organization_name\x18\t \x01(\tBD\x92\x41\x41\x32*Name of the organization of the connectionJ\x13\"Your Organization\"R\x10organizationName\x12u\n\x0cprovider_key\x18\n \x01(\tBR\x92\x41O2CKey ID of the identity provider service that handles authenticationJ\x08\"google\"R\x0bproviderKey\x12\x90\x01\n\x06key_id\x18\x0b \x01(\tBy\x92\x41v2[Alternative identifier for this connection, typically used in frontend applications or URLsJ\x17\"conn_2123312131125533\"R\x05keyId\x12\x90\x01\n\ncreated_at\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.TimestampBU\x92\x41@2&When this connection was first createdJ\x16\"2023-01-15T14:30:00Z\"\xe0\x41\x03\xfa\xd2\xe4\x93\x02\t\x12\x07PREVIEWR\tcreatedAt\"\xcf\x02\n\"ListOrganizationConnectionsRequest\x12\x80\x01\n\tpage_size\x18\x01 \x01(\rBc\x92\x41Y2SMaximum number of organizations to return per page. Value must be between 1 and 30.J\x02\x33\x30\xbaH\x04*\x02\x18\x1eR\x08pageSize\x12\xa5\x01\n\npage_token\x18\x02 \x01(\tB\x85\x01\x92\x41\x81\x01\x32\x61Token from a previous response for pagination. Provide this to retrieve the next page of results.J\x1c\x65yJwYWdlIjoyLCJsaW1pdCI6MzB9R\tpageToken\"\x97\x02\n#ListOrganizationConnectionsResponse\x12&\n\x0fnext_page_token\x18\x01 \x01(\tR\rnextPageToken\x12\x1d\n\ntotal_size\x18\x02 \x01(\rR\ttotalSize\x12&\n\x0fprev_page_token\x18\x03 \x01(\tR\rprevPageToken\x12\x80\x01\n\x0b\x63onnections\x18\x04 \x03(\x0b\x32\'.scalekit.v1.connections.ListConnectionB5\x92\x41\x32\x32\x30List of connections matching the filter criteriaR\x0b\x63onnections\"\xa2\x07\n$SearchOrganizationConnectionsRequest\x12l\n\x05query\x18\x01 \x01(\tBQ\x92\x41G2-Search query Connection ID or Organization IDJ\x16\"conn_121312434123312\"\xbaH\x04r\x02\x18\x64H\x00R\x05query\x88\x01\x01\x12@\n\x08provider\x18\x02 \x01(\tB\x1f\x92\x41\x1c\x32\x12\x46ilter by providerJ\x06\"OKTA\"H\x01R\x08provider\x88\x01\x01\x12}\n\x06status\x18\x03 \x01(\x0e\x32).scalekit.v1.connections.ConnectionStatusB5\x92\x41*2\x1b\x46ilter by connection statusJ\x0b\"COMPLETED\"\xbaH\x05\x82\x01\x02\x10\x01H\x02R\x06status\x88\x01\x01\x12\x8c\x01\n\x0f\x63onnection_type\x18\x04 \x01(\x0e\x32\'.scalekit.v1.connections.ConnectionTypeB5\x92\x41*2\x1b\x46ilter by connection statusJ\x0b\"COMPLETED\"\xbaH\x05\x82\x01\x02\x10\x01H\x03R\x0e\x63onnectionType\x88\x01\x01\x12O\n\x07\x65nabled\x18\x07 \x01(\x08\x42\x30\x92\x41-2#Filter by connection enabled statusJ\x06\"true\"H\x04R\x07\x65nabled\x88\x01\x01\x12\x80\x01\n\tpage_size\x18\x05 \x01(\rBc\x92\x41Y2SMaximum number of organizations to return per page. Value must be between 1 and 30.J\x02\x33\x30\xbaH\x04*\x02\x18\x1eR\x08pageSize\x12\xa5\x01\n\npage_token\x18\x06 \x01(\tB\x85\x01\x92\x41\x81\x01\x32\x61Token from a previous response for pagination. Provide this to retrieve the next page of results.J\x1c\x65yJwYWdlIjoyLCJsaW1pdCI6MzB9R\tpageTokenB\x08\n\x06_queryB\x0b\n\t_providerB\t\n\x07_statusB\x12\n\x10_connection_typeB\n\n\x08_enabled\"\x99\x02\n%SearchOrganizationConnectionsResponse\x12&\n\x0fnext_page_token\x18\x01 \x01(\tR\rnextPageToken\x12\x1d\n\ntotal_size\x18\x02 \x01(\rR\ttotalSize\x12&\n\x0fprev_page_token\x18\x03 \x01(\tR\rprevPageToken\x12\x80\x01\n\x0b\x63onnections\x18\x04 \x03(\x0b\x32\'.scalekit.v1.connections.ListConnectionB5\x92\x41\x32\x32\x30List of connections matching the filter criteriaR\x0b\x63onnections\"\x9c\x01\n\"ToggleEnvironmentConnectionRequest\x12v\n\rconnection_id\x18\x02 \x01(\tBQ\x92\x41\x45\x32+Connection ID. Unique ID for the connectionJ\x16\"conn_121312434123312\"\xbaH\x06r\x04\x10\x01\x18 R\x0c\x63onnectionId\"\x9e\x02\n\x17ToggleConnectionRequest\x12\x92\x01\n\x0forganization_id\x18\x01 \x01(\tBi\x92\x41]2DUnique identifier of the organization associated with the connectionJ\x15\"org_121312434123312\"\xbaH\x06r\x04\x10\x01\x18 R\x0eorganizationId\x12h\n\x02id\x18\x03 \x01(\tBX\x92\x41L22Unique identifier for the connection to be toggledJ\x16\"conn_121312434123312\"\xbaH\x06r\x04\x10\x01\x18 R\x02idJ\x04\x08\x02\x10\x03\"\xbc\x02\n\x18ToggleConnectionResponse\x12\xa9\x01\n\x07\x65nabled\x18\x01 \x01(\x08\x42\x8e\x01\x92\x41\x8a\x01\x32\x81\x01\x43urrent state of the connection after the operation. True means the connection is now enabled and can be used for authentication.J\x04trueR\x07\x65nabled\x12\x62\n\rerror_message\x18\x02 \x01(\tB8\x92\x41\x35\x32$Error message if the operation failsJ\r\"placeholder\"H\x00R\x0c\x65rrorMessage\x88\x01\x01\x42\x10\n\x0e_error_message\"\x9a\x0f\n\x14OIDCConnectionConfig\x12j\n\x06issuer\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValueB4\x92\x41\x31\x32\nIssuer URLJ#\"https://youridp.com/service/oauth\"R\x06issuer\x12\xaa\x01\n\x12\x64iscovery_endpoint\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValueB]\x92\x41Z2\x12\x44iscovery EndpointJD\"https://youridp.com/service/oauth/.well-known/openid-configuration\"R\x11\x64iscoveryEndpoint\x12\x84\x01\n\rauthorize_uri\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValueBA\x92\x41>2\rAuthorize URIJ-\"https://youridp.com/service/oauth/authorize\"R\x0c\x61uthorizeUri\x12t\n\ttoken_uri\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValueB9\x92\x41\x36\x32\tToken URIJ)\"https://youridp.com/service/oauth/token\"R\x08tokenUri\x12\x82\x01\n\ruser_info_uri\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValueB@\x92\x41=2\rUser Info URIJ,\"https://youridp.com/service/oauth/userinfo\"R\x0buserInfoUri\x12p\n\x08jwks_uri\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValueB7\x92\x41\x34\x32\x08JWKS URIJ(\"https://youridp.com/service/oauth/jwks\"R\x07jwksUri\x12\\\n\tclient_id\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValueB!\x92\x41\x1e\x32\tClient IDJ\x11\"oauth_client_id\"R\x08\x63lientId\x12l\n\rclient_secret\x18\t \x01(\x0b\x32\x1c.google.protobuf.StringValueB)\x92\x41&2\rClient SecretJ\x15\"oauth_client_secret\"R\x0c\x63lientSecret\x12\x63\n\x06scopes\x18\n \x03(\x0e\x32\".scalekit.v1.connections.OIDCScopeB\'\x92\x41$2\x0bOIDC ScopesJ\x15[\"openid\", \"profile\"]R\x06scopes\x12r\n\x0ftoken_auth_type\x18\x0b \x01(\x0e\x32&.scalekit.v1.connections.TokenAuthTypeB\"\x92\x41\x1f\x32\x0fToken Auth TypeJ\x0c\"URL_PARAMS\"R\rtokenAuthType\x12j\n\x0credirect_uri\x18\x0c \x01(\tBG\x92\x41\x44\x32\x0cRedirect URIJ4\"https://yourapp.com/sso/v1/oidc/conn_1234/callback\"R\x0bredirectUri\x12V\n\x0cpkce_enabled\x18\r \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\x17\x92\x41\x14\x32\x0cPKCE EnabledJ\x04trueR\x0bpkceEnabled\x12h\n\x13idp_logout_required\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\x1c\x92\x41\x19\x32\x11\x45nable IDP logoutJ\x04trueR\x11idpLogoutRequired\x12\xb4\x01\n\x18post_logout_redirect_uri\x18\x0f \x01(\x0b\x32\x1c.google.protobuf.StringValueB]\x92\x41W2\x18post logout redirect uriJ;\"https://yourapp.com/sso/v1/oidc/conn_1234/logout/callback\"\xe0\x41\x03R\x15postLogoutRedirectUri\x12\xea\x01\n\x1f\x62\x61\x63kchannel_logout_redirect_uri\x18\x10 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\x84\x01\x92\x41~2<backchannel logout redirect uri where idp sends logout_tokenJ>\"https://yourapp.com/sso/v1/oidc/conn_1234/backchannel-logout\"\xe0\x41\x03R\x1c\x62\x61\x63kchannelLogoutRedirectUri\"\x85\t\n\x15OAuthConnectionConfig\x12\x84\x01\n\rauthorize_uri\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValueBA\x92\x41>2\rAuthorize URIJ-\"https://youridp.com/service/oauth/authorize\"R\x0c\x61uthorizeUri\x12t\n\ttoken_uri\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValueB9\x92\x41\x36\x32\tToken URIJ)\"https://youridp.com/service/oauth/token\"R\x08tokenUri\x12\x82\x01\n\ruser_info_uri\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValueB@\x92\x41=2\rUser Info URIJ,\"https://youridp.com/service/oauth/userinfo\"R\x0buserInfoUri\x12\\\n\tclient_id\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValueB!\x92\x41\x1e\x32\tClient IDJ\x11\"oauth_client_id\"R\x08\x63lientId\x12l\n\rclient_secret\x18\t \x01(\x0b\x32\x1c.google.protobuf.StringValueB)\x92\x41&2\rClient SecretJ\x15\"oauth_client_secret\"R\x0c\x63lientSecret\x12?\n\x06scopes\x18\n \x03(\tB\'\x92\x41$2\x0bOIDC ScopesJ\x15[\"openid\", \"profile\"]R\x06scopes\x12\x62\n\x0credirect_uri\x18\x0c \x01(\tB?\x92\x41<2\x0cRedirect URIJ,\"https://yourapp.com/service/oauth/redirect\"R\x0bredirectUri\x12V\n\x0cpkce_enabled\x18\r \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\x17\x92\x41\x14\x32\x0cPKCE EnabledJ\x04trueR\x0bpkceEnabled\x12V\n\x06prompt\x18\x0e \x01(\x0b\x32\x1c.google.protobuf.StringValueB \x92\x41\x1d\x32\x13Prompt for the userJ\x06\"none\"R\x06prompt\x12m\n\x12use_platform_creds\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.BoolValueB#\x92\x41 2\x18Use Scalekit credentialsJ\x04trueR\x10usePlatformCreds\x12Z\n\x0b\x61\x63\x63\x65ss_type\x18\x10 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\x1b\x92\x41\x18\x32\x0b\x41\x63\x63\x65ss TypeJ\t\"offline\"R\naccessType\"\xf4\x07\n\x12PasswordLessConfig\x12]\n\x04type\x18\x01 \x01(\x0e\x32).scalekit.v1.connections.PasswordlessTypeB\x1e\x92\x41\x1b\x32\x11Passwordless TypeJ\x06\"LINK\"R\x04type\x12W\n\tfrequency\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x16\x92\x41\x13\x32\x0eLink FrequencyJ\x01\x31H\x00R\tfrequency\x88\x01\x01\x12\x61\n\x08validity\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\"\x92\x41\x1f\x32\x18Link Validity in SecondsJ\x03\x36\x30\x30H\x01R\x08validity\x88\x01\x01\x12\x86\x01\n\x1b\x65nforce_same_browser_origin\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValueB&\x92\x41#2\x1b\x45nforce Same Browser OriginJ\x04trueH\x02R\x18\x65nforceSameBrowserOrigin\x88\x01\x01\x12t\n\x15\x63ode_challenge_length\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x1d\x92\x41\x1a\x32\x15\x43ode Challenge LengthJ\x01\x36H\x03R\x13\x63odeChallengeLength\x88\x01\x01\x12\x84\x01\n\x13\x63ode_challenge_type\x18\x06 \x01(\x0e\x32*.scalekit.v1.connections.CodeChallengeTypeB#\x92\x41 2\x13\x43ode Challenge TypeJ\t\"NUMERIC\"H\x04R\x11\x63odeChallengeType\x88\x01\x01\x12\x9d\x01\n-regenerate_passwordless_credentials_on_resend\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\x1a\x92\x41\x17\x32\x0fRegenerate the J\x04trueH\x05R)regeneratePasswordlessCredentialsOnResend\x88\x01\x01\x42\x0c\n\n_frequencyB\x0b\n\t_validityB\x1e\n\x1c_enforce_same_browser_originB\x18\n\x16_code_challenge_lengthB\x16\n\x14_code_challenge_typeB0\n._regenerate_passwordless_credentials_on_resend\"P\n\x10StaticAuthConfig\x12<\n\rstatic_config\x18\x01 \x01(\x0b\x32\x17.google.protobuf.StructR\x0cstaticConfig\"\xab\x0f\n\x1bSAMLConnectionConfigRequest\x12\x8a\x01\n\x10idp_metadata_url\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValueBB\x92\x41?2\x10IDP Metadata URLJ+\"https://youridp.com/service/saml/metadata\"R\x0eidpMetadataUrl\x12x\n\ridp_entity_id\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValueB6\x92\x41\x33\x32\rIDP Entity IDJ\"\"https://youridp.com/service/saml\"R\x0bidpEntityId\x12v\n\x0bidp_sso_url\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValueB8\x92\x41\x35\x32\x0bIDP SSO URLJ&\"https://youridp.com/service/saml/sso\"R\tidpSsoUrl\x12[\n\x0fidp_certificate\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\x14\x92\x41\x11\x32\x0fIDP CertificateR\x0eidpCertificate\x12v\n\x0bidp_slo_url\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValueB8\x92\x41\x35\x32\x0bIDP SLO URLJ&\"https://youridp.com/service/saml/slo\"R\tidpSloUrl\x12l\n\x0fui_button_title\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValueB&\x92\x41#2\x0fUI Button TitleJ\x10\"Login with SSO\"R\ruiButtonTitle\x12t\n\x12idp_name_id_format\x18\x07 \x01(\x0e\x32%.scalekit.v1.connections.NameIdFormatB \x92\x41\x1d\x32\x12IDP Name ID FormatJ\x07\"EMAIL\"R\x0fidpNameIdFormat\x12\x89\x01\n\x17idp_sso_request_binding\x18\x08 \x01(\x0e\x32\'.scalekit.v1.connections.RequestBindingB)\x92\x41&2\x17IDP SSO Request BindingJ\x0b\"HTTP_POST\"R\x14idpSsoRequestBinding\x12\x8d\x01\n\x17idp_slo_request_binding\x18\t \x01(\x0e\x32\'.scalekit.v1.connections.RequestBindingB-\x92\x41*2\x17IDP SLO Request BindingJ\x0f\"HTTP_REDIRECT\"R\x14idpSloRequestBinding\x12\x93\x01\n\x13saml_signing_option\x18\n \x01(\x0e\x32+.scalekit.v1.connections.SAMLSigningOptionsB6\x92\x41\x33\x32\x13SAML Signing OptionJ\x1c\"SAML_ONLY_RESPONSE_SIGNING\"R\x11samlSigningOption\x12S\n\x0b\x66orce_authn\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\x16\x92\x41\x13\x32\x0b\x46orce AuthnJ\x04trueR\nforceAuthn\x12\x96\x01\n\x14\x64\x65\x66\x61ult_redirect_uri\x18\x0f \x01(\x0b\x32\x1c.google.protobuf.StringValueBF\x92\x41\x43\x32\x14\x44\x65\x66\x61ult Redirect URIJ+\"https://yourapp.com/service/saml/redirect\"R\x12\x64\x65\x66\x61ultRedirectUri\x12k\n\x13\x61ssertion_encrypted\x18\x10 \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\x1e\x92\x41\x1b\x32\x13\x41ssertion EncryptedJ\x04trueR\x12\x61ssertionEncrypted\x12j\n\x13want_request_signed\x18\x11 \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\x1e\x92\x41\x1b\x32\x13Want Request SignedJ\x04trueR\x11wantRequestSigned\x12q\n\x0e\x63\x65rtificate_id\x18\x12 \x01(\x0b\x32\x1c.google.protobuf.StringValueB,\x92\x41)2\x0e\x43\x65rtificate IDJ\x17\"cer_35585423166144613\"R\rcertificateId\x12\x62\n\x10idp_slo_required\x18\x13 \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\x1c\x92\x41\x19\x32\x11\x45nable IDP logoutJ\x04trueR\x0eidpSloRequiredJ\x04\x08\x0b\x10\x0c\"\xf9\x13\n\x1cSAMLConnectionConfigResponse\x12W\n\x0csp_entity_id\x18\x01 \x01(\tB5\x92\x41\x32\x32\x0cSP Entity IDJ\"\"https://yourapp.com/service/saml\"R\nspEntityId\x12m\n\x10sp_assertion_url\x18\x02 \x01(\tBC\x92\x41@2\x10SP Assertion URLJ,\"https://youridp.com/service/saml/assertion\"R\x0espAssertionUrl\x12i\n\x0fsp_metadata_url\x18\x03 \x01(\tBA\x92\x41>2\x0fSP Metadata URLJ+\"https://youridp.com/service/saml/metadata\"R\rspMetadataUrl\x12\x8a\x01\n\x10idp_metadata_url\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValueBB\x92\x41?2\x10IDP Metadata URLJ+\"https://youridp.com/service/saml/metadata\"R\x0eidpMetadataUrl\x12x\n\ridp_entity_id\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValueB6\x92\x41\x33\x32\rIDP Entity IDJ\"\"https://youridp.com/service/saml\"R\x0bidpEntityId\x12v\n\x0bidp_sso_url\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValueB8\x92\x41\x35\x32\x0bIDP SSO URLJ&\"https://youridp.com/service/saml/sso\"R\tidpSsoUrl\x12i\n\x10idp_certificates\x18\x07 \x03(\x0b\x32\'.scalekit.v1.connections.IDPCertificateB\x15\x92\x41\x12\x32\x10IDP CertificatesR\x0fidpCertificates\x12v\n\x0bidp_slo_url\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValueB8\x92\x41\x35\x32\x0bIDP SLO URLJ&\"https://youridp.com/service/saml/slo\"R\tidpSloUrl\x12l\n\x0fui_button_title\x18\t \x01(\x0b\x32\x1c.google.protobuf.StringValueB&\x92\x41#2\x0fUI Button TitleJ\x10\"Login with SSO\"R\ruiButtonTitle\x12t\n\x12idp_name_id_format\x18\n \x01(\x0e\x32%.scalekit.v1.connections.NameIdFormatB \x92\x41\x1d\x32\x12IDP Name ID FormatJ\x07\"EMAIL\"R\x0fidpNameIdFormat\x12\x89\x01\n\x17idp_sso_request_binding\x18\x0b \x01(\x0e\x32\'.scalekit.v1.connections.RequestBindingB)\x92\x41&2\x17IDP SSO Request BindingJ\x0b\"HTTP_POST\"R\x14idpSsoRequestBinding\x12\x89\x01\n\x17idp_slo_request_binding\x18\x0c \x01(\x0e\x32\'.scalekit.v1.connections.RequestBindingB)\x92\x41&2\x17IDP SLO Request BindingJ\x0b\"HTTP_POST\"R\x14idpSloRequestBinding\x12\x93\x01\n\x13saml_signing_option\x18\r \x01(\x0e\x32+.scalekit.v1.connections.SAMLSigningOptionsB6\x92\x41\x33\x32\x13SAML Signing OptionJ\x1c\"SAML_ONLY_RESPONSE_SIGNING\"R\x11samlSigningOption\x12{\n\x19\x61llow_idp_initiated_login\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.BoolValueB$\x92\x41!2\x19\x41llow IDP Initiated LoginJ\x04trueR\x16\x61llowIdpInitiatedLogin\x12S\n\x0b\x66orce_authn\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\x16\x92\x41\x13\x32\x0b\x46orce AuthnJ\x04trueR\nforceAuthn\x12\x96\x01\n\x14\x64\x65\x66\x61ult_redirect_uri\x18\x10 \x01(\x0b\x32\x1c.google.protobuf.StringValueBF\x92\x41\x43\x32\x14\x44\x65\x66\x61ult Redirect URIJ+\"https://yourapp.com/service/saml/redirect\"R\x12\x64\x65\x66\x61ultRedirectUri\x12k\n\x13\x61ssertion_encrypted\x18\x11 \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\x1e\x92\x41\x1b\x32\x13\x41ssertion EncryptedJ\x04trueR\x12\x61ssertionEncrypted\x12j\n\x13want_request_signed\x18\x12 \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\x1e\x92\x41\x1b\x32\x13Want Request SignedJ\x04trueR\x11wantRequestSigned\x12q\n\x0e\x63\x65rtificate_id\x18\x13 \x01(\x0b\x32\x1c.google.protobuf.StringValueB,\x92\x41)2\x0e\x43\x65rtificate IDJ\x17\"cer_35585423166144613\"R\rcertificateId\x12\x62\n\x10idp_slo_required\x18\x14 \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\x1c\x92\x41\x19\x32\x11\x45nable IDP logoutJ\x04trueR\x0eidpSloRequired\x12\x96\x01\n\nsp_slo_url\x18\x15 \x01(\x0b\x32\x1c.google.protobuf.StringValueBZ\x92\x41T2\x18Service Provider SLO urlJ8\"https://yourapp.com/sso/v1/saml/conn_1234/slo/callback\"\xe0\x41\x03R\x08spSloUrl\"\xbf\x03\n\x0eIDPCertificate\x12\x36\n\x0b\x63\x65rtificate\x18\x01 \x01(\tB\x14\x92\x41\x11\x32\x0fIDP CertificateR\x0b\x63\x65rtificate\x12s\n\x0b\x63reate_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB6\x92\x41\x33\x32\x19\x43\x65rtificate Creation TimeJ\x16\"2021-09-01T00:00:00Z\"R\ncreateTime\x12q\n\x0b\x65xpiry_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB4\x92\x41\x31\x32\x17\x43\x65rtificate Expiry TimeJ\x16\"2021-09-01T00:00:00Z\"R\nexpiryTime\x12\x38\n\x02id\x18\x04 \x01(\tB(\x92\x41%2\x0e\x43\x65rtificate IDJ\x13\"cert_123123123123\"R\x02id\x12S\n\x06issuer\x18\x05 \x01(\tB;\x92\x41\x38\x32\x12\x43\x65rtificate IssuerJ\"\"https://youridp.com/service/saml\"R\x06issuer\"b\n\x16GetOIDCMetadataRequest\x12H\n\x08metadata\x18\x01 \x01(\x0b\x32,.scalekit.v1.connections.OIDCMetadataRequestR\x08metadata\"9\n\x13OIDCMetadataRequest\x12\"\n\x06issuer\x18\x01 \x01(\tB\n\xbaH\x07r\x05\x10\x01\x18\xc8\x01R\x06issuer\"\xd7\x01\n\x17GetOIDCMetadataResponse\x12\x16\n\x06issuer\x18\x01 \x01(\tR\x06issuer\x12\x35\n\x16\x61uthorization_endpoint\x18\x02 \x01(\tR\x15\x61uthorizationEndpoint\x12%\n\x0etoken_endpoint\x18\x03 \x01(\tR\rtokenEndpoint\x12+\n\x11userinfo_endpoint\x18\x04 \x01(\tR\x10userinfoEndpoint\x12\x19\n\x08jwks_uri\x18\x05 \x01(\tR\x07jwksUri\"b\n\x16GetSAMLMetadataRequest\x12H\n\x08metadata\x18\x01 \x01(\x0b\x32,.scalekit.v1.connections.SAMLMetadataRequestR\x08metadata\"D\n\x13SAMLMetadataRequest\x12-\n\x0cmetadata_url\x18\x01 \x01(\tB\n\xbaH\x07r\x05\x10\x01\x18\xc8\x01R\x0bmetadataUrl\"\xb4\x02\n\x17GetSAMLMetadataResponse\x12\"\n\ridp_entity_id\x18\x01 \x01(\tR\x0bidpEntityId\x12\x1e\n\x0bidp_sso_url\x18\x02 \x01(\tR\tidpSsoUrl\x12\x1e\n\x0bidp_slo_url\x18\x03 \x01(\tR\tidpSloUrl\x12)\n\x10idp_certificates\x18\x04 \x03(\tR\x0fidpCertificates\x12+\n\x12idp_name_id_format\x18\x05 \x01(\tR\x0fidpNameIdFormat\x12\'\n\x0frequest_binding\x18\x06 \x01(\tR\x0erequestBinding\x12\x34\n\x16want_assertions_signed\x18\x07 \x01(\x08R\x14wantAssertionsSigned\"u\n GetSAMLCertificateDetailsRequest\x12Q\n\x0b\x63\x65rtificate\x18\x01 \x01(\x0b\x32/.scalekit.v1.connections.SAMLCertificateRequestR\x0b\x63\x65rtificate\"5\n\x16SAMLCertificateRequest\x12\x1b\n\x04text\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x04text\"\xa5\x01\n!GetSAMLCertificateDetailsResponse\x12\x12\n\x04text\x18\x01 \x01(\tR\x04text\x12\x1b\n\tnot_after\x18\x02 \x01(\x03R\x08notAfter\x12\x1d\n\nnot_before\x18\x03 \x01(\x03R\tnotBefore\x12\x18\n\x07subject\x18\x04 \x01(\tR\x07subject\x12\x16\n\x06issuer\x18\x05 \x01(\tR\x06issuer\"\x86\x01\n\x1eGetConnectionTestResultRequest\x12,\n\rconnection_id\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x0c\x63onnectionId\x12\x36\n\x0ftest_request_id\x18\x02 \x01(\tB\x0e\xbaH\x0br\t\x10\x01:\x05test_R\rtestRequestId\"\xbd\x02\n\x1fGetConnectionTestResultResponse\x12\x41\n\x06status\x18\x01 \x01(\x0e\x32).scalekit.v1.connections.TestResultStatusR\x06status\x12 \n\tuser_info\x18\x02 \x01(\tH\x00R\x08userInfo\x88\x01\x01\x12\x19\n\x05\x65rror\x18\x03 \x01(\tH\x01R\x05\x65rror\x88\x01\x01\x12\x30\n\x11\x65rror_description\x18\x04 \x01(\tH\x02R\x10\x65rrorDescription\x88\x01\x01\x12(\n\rerror_details\x18\x05 \x01(\tH\x03R\x0c\x65rrorDetails\x88\x01\x01\x42\x0c\n\n_user_infoB\x08\n\x06_errorB\x14\n\x12_error_descriptionB\x10\n\x0e_error_details\"\x1a\n\x18PasswordConnectionConfig\"9\n\x05\x46lags\x12\x19\n\x08is_login\x18\x01 \x01(\x08R\x07isLogin\x12\x15\n\x06is_app\x18\x02 \x01(\x08R\x05isApp\"\xaa\x03\n\x19ListAppConnectionsRequest\x12\x80\x01\n\tpage_size\x18\x01 \x01(\rBc\x92\x41Y2SMaximum number of organizations to return per page. Value must be between 1 and 30.J\x02\x33\x30\xbaH\x04*\x02\x18\x1eR\x08pageSize\x12\xa5\x01\n\npage_token\x18\x02 \x01(\tB\x85\x01\x92\x41\x81\x01\x32\x61Token from a previous response for pagination. Provide this to retrieve the next page of results.J\x1c\x65yJwYWdlIjoyLCJsaW1pdCI6MzB9R\tpageToken\x12U\n\x08provider\x18\x03 \x01(\tB4\x92\x41(2\x1e\x46ilter connections by providerJ\x06\"OKTA\"\xbaH\x06r\x04\x10\x01\x18\x32H\x00R\x08provider\x88\x01\x01\x42\x0b\n\t_provider\"\xea\x03\n\x1aListAppConnectionsResponse\x12\x81\x01\n\x0b\x63onnections\x18\x01 \x03(\x0b\x32\'.scalekit.v1.connections.ListConnectionB6\x92\x41\x33\x32\x31List of connections matching the request criteriaR\x0b\x63onnections\x12o\n\x0fnext_page_token\x18\x02 \x01(\tBG\x92\x41\x44\x32\"Token for the next page of resultsJ\x1e\"eyJwYWdlIjoyLCJsaW1pdCI6MzB9\"R\rnextPageToken\x12s\n\x0fprev_page_token\x18\x03 \x01(\tBK\x92\x41H2&Token for the previous page of resultsJ\x1e\"eyJwYWdlIjoyLCJsaW1pdCI6MzB9\"R\rprevPageToken\x12\x62\n\ntotal_size\x18\x04 \x01(\rBC\x92\x41@29Total number of connections matching the request criteriaJ\x03\x31\x30\x30R\ttotalSize*W\n\x11\x43odeChallengeType\x12#\n\x1f\x43ODE_CHALLENGE_TYPE_UNSPECIFIED\x10\x00\x12\x0b\n\x07NUMERIC\x10\x01\x12\x10\n\x0c\x41LPHANUMERIC\x10\x02*R\n\x11\x43onfigurationType\x12\"\n\x1e\x43ONFIGURATION_TYPE_UNSPECIFIED\x10\x00\x12\r\n\tDISCOVERY\x10\x01\x12\n\n\x06MANUAL\x10\x02*a\n\x0cNameIdFormat\x12\x16\n\x12NAME_ID_FORMAT_NIL\x10\x00\x12\x0f\n\x0bUNSPECIFIED\x10\x01\x12\t\n\x05\x45MAIL\x10\x02\x12\r\n\tTRANSIENT\x10\x03\x12\x0e\n\nPERSISTENT\x10\x04*U\n\x10PasswordlessType\x12 \n\x1cPasswordlessType_UNSPECIFIED\x10\x00\x12\x08\n\x04LINK\x10\x01\x12\x07\n\x03OTP\x10\x02\x12\x0c\n\x08LINK_OTP\x10\x03*9\n\x10TestResultStatus\x12\x0b\n\x07PENDING\x10\x00\x12\x0b\n\x07SUCCESS\x10\x01\x12\x0b\n\x07\x46\x41ILURE\x10\x02*\xd8\x01\n\x12SAMLSigningOptions\x12$\n SAML_SIGNING_OPTIONS_UNSPECIFIED\x10\x00\x12\x0e\n\nNO_SIGNING\x10\x01\x12\x1e\n\x1aSAML_ONLY_RESPONSE_SIGNING\x10\x02\x12\x1f\n\x1bSAML_ONLY_ASSERTION_SIGNING\x10\x03\x12#\n\x1fSAML_RESPONSE_ASSERTION_SIGNING\x10\x04\x12&\n\"SAML_RESPONSE_OR_ASSERTION_SIGNING\x10\x05*S\n\x0eRequestBinding\x12\x1f\n\x1bREQUEST_BINDING_UNSPECIFIED\x10\x00\x12\r\n\tHTTP_POST\x10\x01\x12\x11\n\rHTTP_REDIRECT\x10\x02*P\n\rTokenAuthType\x12\x1f\n\x1bTOKEN_AUTH_TYPE_UNSPECIFIED\x10\x00\x12\x0e\n\nURL_PARAMS\x10\x01\x12\x0e\n\nBASIC_AUTH\x10\x02*c\n\tOIDCScope\x12\x1a\n\x16OIDC_SCOPE_UNSPECIFIED\x10\x00\x12\n\n\x06openid\x10\x01\x12\x0b\n\x07profile\x10\x02\x12\t\n\x05\x65mail\x10\x03\x12\x0b\n\x07\x61\x64\x64ress\x10\x04\x12\t\n\x05phone\x10\x05*\x80\x01\n\x0e\x43onnectionType\x12\x0b\n\x07INVALID\x10\x00\x12\x08\n\x04OIDC\x10\x01\x12\x08\n\x04SAML\x10\x02\x12\x0c\n\x08PASSWORD\x10\x03\x12\t\n\x05OAUTH\x10\x04\x12\x10\n\x0cPASSWORDLESS\x10\x05\x12\t\n\x05\x42\x41SIC\x10\x06\x12\n\n\x06\x42\x45\x41RER\x10\x07\x12\x0b\n\x07\x41PI_KEY\x10\x08*`\n\x10\x43onnectionStatus\x12!\n\x1d\x43ONNECTION_STATUS_UNSPECIFIED\x10\x00\x12\t\n\x05\x44RAFT\x10\x01\x12\x0f\n\x0bIN_PROGRESS\x10\x02\x12\r\n\tCOMPLETED\x10\x03*\x98\x02\n\x12\x43onnectionProvider\x12#\n\x1f\x43ONNECTION_PROVIDER_UNSPECIFIED\x10\x00\x12\x08\n\x04OKTA\x10\x01\x12\n\n\x06GOOGLE\x10\x02\x12\x10\n\x0cMICROSOFT_AD\x10\x03\x12\t\n\x05\x41UTH0\x10\x04\x12\x0c\n\x08ONELOGIN\x10\x05\x12\x11\n\rPING_IDENTITY\x10\x06\x12\r\n\tJUMPCLOUD\x10\x07\x12\n\n\x06\x43USTOM\x10\x08\x12\n\n\x06GITHUB\x10\t\x12\n\n\x06GITLAB\x10\n\x12\x0c\n\x08LINKEDIN\x10\x0b\x12\x0e\n\nSALESFORCE\x10\x0c\x12\r\n\tMICROSOFT\x10\r\x12\x11\n\rIDP_SIMULATOR\x10\x0e\x12\x0c\n\x08SCALEKIT\x10\x0f\x12\x08\n\x04\x41\x44\x46S\x10\x10\x32\x88h\n\x11\x43onnectionService\x12\x91\x03\n\x1b\x43reateEnvironmentConnection\x12;.scalekit.v1.connections.CreateEnvironmentConnectionRequest\x1a\x31.scalekit.v1.connections.CreateConnectionResponse\"\x81\x02\x92\x41\xc1\x01\n\x0b\x43onnections\x12\x17\x43reate a new connection\x1a\x38\x45stablish a new connection for the specified environmentJ_\n\x03\x32\x30\x31\x12X\n\x1f\x43onnection created successfully\x12\x35\n3\x1a\x31.scalekit.v1.connections.CreateConnectionResponse\x82\xb5\x18\x02\x18T\xfa\xd2\xe4\x93\x02\t\x12\x07PREVIEW\x82\xd3\xe4\x93\x02!\"\x13/api/v1/connections:\nconnection\x12\x96\x08\n\x10\x43reateConnection\x12\x30.scalekit.v1.connections.CreateConnectionRequest\x1a\x31.scalekit.v1.connections.CreateConnectionResponse\"\x9c\x07\x92\x41\xbc\x06\n\x0b\x43onnections\x12\x17\x43reate a new connection\x1a=Establish a new SSO connection for the specified organizationJ_\n\x03\x32\x30\x31\x12X\n\x1f\x43onnection created successfully\x12\x35\n3\x1a\x31.scalekit.v1.connections.CreateConnectionResponsej\xf3\x04\n\rx-codeSamples\x12\xe1\x04\x32\xde\x04\n\x99\x01*\x96\x01\n\x16\n\x05label\x12\r\x1a\x0bNode.js SDK\n\x14\n\x04lang\x12\x0c\x1a\njavascript\nf\n\x06source\x12\\\x1aZconst connection = await sc.connection.createConnection(organizationId, connectionConfig);\n\x90\x01*\x8d\x01\n\x15\n\x05label\x12\x0c\x1a\nPython SDK\n\x10\n\x04lang\x12\x08\x1a\x06python\nb\n\x06source\x12X\x1aVconnection = sc.connection.create_connection(\n  organization_id,\n  connection_config\n)\n\x93\x01*\x90\x01\n\x11\n\x05label\x12\x08\x1a\x06Go SDK\n\x0c\n\x04lang\x12\x04\x1a\x02go\nm\n\x06source\x12\x63\x1a\x61\x63onnection, err := sc.Connection.CreateConnection(\n  ctx,\n  organizationId,\n  connectionConfig,\n)\n\x96\x01*\x93\x01\n\x13\n\x05label\x12\n\x1a\x08Java SDK\n\x0e\n\x04lang\x12\x06\x1a\x04java\nl\n\x06source\x12\x62\x1a`Connection connection = client.connections().createConnection(organizationId, connectionConfig);\x82\xb5\x18\x02\x18t\xfa\xd2\xe4\x93\x02\t\x12\x07PREVIEW\x82\xd3\xe4\x93\x02\x41\"3/api/v1/organizations/{organization_id}/connections:\nconnection\x12\xba\x04\n\x19\x41ssignDomainsToConnection\x12\x39.scalekit.v1.connections.AssignDomainsToConnectionRequest\x1a:.scalekit.v1.connections.AssignDomainsToConnectionResponse\"\xa5\x03\x92\x41\xb6\x02\n\x0b\x43onnections\x12\x1e\x41ssign domains to a connection\x1a\x9e\x01\x41ssigns one or more domains to a specific connection within an organization. This allows the connection to be used for authentication on the specified domainsJf\n\x03\x32\x30\x30\x12_\n\x1d\x44omains assigned successfully\x12>\n<\x1a:.scalekit.v1.connections.AssignDomainsToConnectionResponse\x82\xb5\x18\x02\x18t\xfa\xd2\xe4\x93\x02\t\x12\x07PREVIEW\x82\xd3\xe4\x93\x02P\x1aK/api/v1/organizations/{organization_id}/connections/{connection_id}/domains:\x01*\x12\xb2\x03\n\x18GetEnvironmentConnection\x12\x38.scalekit.v1.connections.GetEnvironmentConnectionRequest\x1a..scalekit.v1.connections.GetConnectionResponse\"\xab\x02\x92\x41\xe7\x01\n\x0b\x43onnections\x12\x1bRetrieve connection details\x1aSObtain detailed information about a specific connection using its unique identifierJf\n\x03\x32\x30\x30\x12_\n)Successfully retrieved connection details\x12\x32\n0\x1a..scalekit.v1.connections.GetConnectionResponse\x82\xb5\x18\x02\x18T\xfa\xd2\xe4\x93\x02\t\x12\x07PREVIEW\x82\xd3\xe4\x93\x02%\x12#/api/v1/connections/{connection_id}\x12\xa1\t\n\rGetConnection\x12-.scalekit.v1.connections.GetConnectionRequest\x1a..scalekit.v1.connections.GetConnectionResponse\"\xb0\x08\x92\x41\xe6\x07\n\x0b\x43onnections\x12\x16Get connection details\x1a\xd1\x01Retrieves the complete configuration and status details for a specific connection by its ID within an organization. Returns all connection properties including provider settings, protocols, and current status.J\x85\x01\n\x03\x32\x30\x30\x12~\nHSuccessfully retrieved connection details for the specified organization\x12\x32\n0\x1a..scalekit.v1.connections.GetConnectionResponsej\xe2\x04\n\rx-codeSamples\x12\xd0\x04\x32\xcd\x04\n\x98\x01*\x95\x01\n\x16\n\x05label\x12\r\x1a\x0bNode.js SDK\n\x14\n\x04lang\x12\x0c\x1a\njavascript\ne\n\x06source\x12[\x1aYconst connection = await sc.connection.getConnection(\n  organizationId,\n  connectionId\n);\n\x8a\x01*\x87\x01\n\x15\n\x05label\x12\x0c\x1a\nPython SDK\n\x10\n\x04lang\x12\x08\x1a\x06python\n\\\n\x06source\x12R\x1aPconnection = sc.connection.get_connection(\n  organization_id,\n  connection_id,\n)\n\x8c\x01*\x89\x01\n\x11\n\x05label\x12\x08\x1a\x06Go SDK\n\x0c\n\x04lang\x12\x04\x1a\x02go\nf\n\x06source\x12\\\x1aZconnection, err := sc.Connection.GetConnection(\n  ctx,\n  organizationId,\n  connectionId,\n)\n\x93\x01*\x90\x01\n\x13\n\x05label\x12\n\x1a\x08Java SDK\n\x0e\n\x04lang\x12\x06\x1a\x04java\ni\n\x06source\x12_\x1a]Connection connection = client.connections().getConnectionById(connectionId, organizationId);\x82\xb5\x18\x02\x18t\x82\xd3\xe4\x93\x02:\x12\x38/api/v1/organizations/{organization_id}/connections/{id}\x12\xbf\x0c\n\x0fListConnections\x12/.scalekit.v1.connections.ListConnectionsRequest\x1a\x30.scalekit.v1.connections.ListConnectionsResponse\"\xc8\x0b\x92\x41\xa3\x0b\n\x0b\x43onnections\x12\x10List connections\x1a\x32Retrieves a list of connections in the environmentJa\n\x03\x32\x30\x30\x12Z\n\"Successfully retrieved connections\x12\x34\n2\x1a\x30.scalekit.v1.connections.ListConnectionsResponsej\xea\t\n\rx-codeSamples\x12\xd8\t2\xd5\t\n\xa5\x02*\xa2\x02\n\x16\n\x05label\x12\r\x1a\x0bNode.js SDK\n\x14\n\x04lang\x12\x0c\x1a\njavascript\n\xf1\x01\n\x06source\x12\xe6\x01\x1a\xe3\x01// List connections by organization id\nconst connections = await scalekit.connection.listConnections(organizationId);\n\n// List connections by domain\nconst connections = await scalekit.connection.listConnectionsByDomain(domain);\n\xa6\x02*\xa3\x02\n\x15\n\x05label\x12\x0c\x1a\nPython SDK\n\x10\n\x04lang\x12\x08\x1a\x06python\n\xf7\x01\n\x06source\x12\xec\x01\x1a\xe9\x01# List connections by organization id\nconnections = scalekit_client.connection.list_connections(\n  organization_id\n)\n\n# List connections by domain\nresponse = scalekit_client.connection.list_connections_by_domain(domain=\"example.com\")\n\xad\x02*\xaa\x02\n\x11\n\x05label\x12\x08\x1a\x06Go SDK\n\x0c\n\x04lang\x12\x04\x1a\x02go\n\x86\x02\n\x06source\x12\xfb\x01\x1a\xf8\x01// List connections by organization id\nconnections, err := scalekitClient.Connection().ListConnections(\n  ctx,\n  organizationId\n)\n\n// List connections by domain\nconnections, err := scalekitClient.Connection().ListConnectionsByDomain(ctx, \n  domain)\n\xd1\x02*\xce\x02\n\x13\n\x05label\x12\n\x1a\x08Java SDK\n\x0e\n\x04lang\x12\x06\x1a\x04java\n\xa6\x02\n\x06source\x12\x9b\x02\x1a\x98\x02// List connections by organization id\nListConnectionsResponse response = scalekitClient.connections(\n  ).listConnections(organizationId);\n\n// List connections by domain\nListConnectionsResponse response = scalekitClient.connections(\n  ).listConnectionsByDomain(\"your-domain.com\");\x82\xb5\x18\x02\x18t\x82\xd3\xe4\x93\x02\x15\x12\x13/api/v1/connections\x12\xb5\x03\n\x1bListOrganizationConnections\x12;.scalekit.v1.connections.ListOrganizationConnectionsRequest\x1a<.scalekit.v1.connections.ListOrganizationConnectionsResponse\"\x9a\x02\x92\x41\xd6\x01\n\x0b\x43onnections\x12\x1dList organization connections\x1a\x39Retrieves a list of connections for all the organizationsJm\n\x03\x32\x30\x30\x12\x66\n\"Successfully retrieved connections\x12@\n>\x1a<.scalekit.v1.connections.ListOrganizationConnectionsResponse\x82\xb5\x18\x02\x18T\xfa\xd2\xe4\x93\x02\t\x12\x07PREVIEW\x82\xd3\xe4\x93\x02%\x12#/api/v1/organizations/-/connections\x12\xcd\x03\n\x1dSearchOrganizationConnections\x12=.scalekit.v1.connections.SearchOrganizationConnectionsRequest\x1a>.scalekit.v1.connections.SearchOrganizationConnectionsResponse\"\xac\x02\x92\x41\xe1\x01\n\x0b\x43onnections\x12\x1fSearch organization connections\x1a\x44Search with query or filters provided and return list of connectionsJk\n\x03\x32\x30\x30\x12\x64\n\x1eSuccessfully found connections\x12\x42\n@\x1a>.scalekit.v1.connections.SearchOrganizationConnectionsResponse\x82\xb5\x18\x02\x18T\xfa\xd2\xe4\x93\x02\t\x12\x07PREVIEW\x82\xd3\xe4\x93\x02,\x12*/api/v1/organizations/-/connections:search\x12\xf1\x02\n\x1bUpdateEnvironmentConnection\x12;.scalekit.v1.connections.UpdateEnvironmentConnectionRequest\x1a\x31.scalekit.v1.connections.UpdateConnectionResponse\"\xe1\x01\x92\x41\x91\x01\n\x0b\x43onnections\x12\x13Update a connection\x1a\x17Update a SSO ConnectionJT\n\x03\x32\x30\x30\x12M\n\x14Updated Successfully\x12\x35\n3\x1a\x31.scalekit.v1.connections.UpdateConnectionResponse\x82\xb5\x18\x02\x18T\xfa\xd2\xe4\x93\x02\t\x12\x07PREVIEW\x82\xd3\xe4\x93\x02\x31\x32#/api/v1/connections/{connection_id}:\nconnection\x12\xb4\x08\n\x10UpdateConnection\x12\x30.scalekit.v1.connections.UpdateConnectionRequest\x1a\x31.scalekit.v1.connections.UpdateConnectionResponse\"\xba\x07\x92\x41\xd5\x06\n\x0b\x43onnections\x12$Update a connection for organization\x1a\x17Update a SSO ConnectionJT\n\x03\x32\x30\x30\x12M\n\x14Updated Successfully\x12\x35\n3\x1a\x31.scalekit.v1.connections.UpdateConnectionResponsej\xb0\x05\n\rx-codeSamples\x12\x9e\x05\x32\x9b\x05\n\xa7\x01*\xa4\x01\n\x16\n\x05label\x12\r\x1a\x0bNode.js SDK\n\x14\n\x04lang\x12\x0c\x1a\njavascript\nt\n\x06source\x12j\x1ahconst connection = await sc.connection.updateConnection(organizationId, connectionId, connectionConfig);\n\xa1\x01*\x9e\x01\n\x15\n\x05label\x12\x0c\x1a\nPython SDK\n\x10\n\x04lang\x12\x08\x1a\x06python\ns\n\x06source\x12i\x1agconnection = sc.connection.update_connection(\n  organization_id,\n  connection_id,\n  connection_config\n)\n\xa3\x01*\xa0\x01\n\x11\n\x05label\x12\x08\x1a\x06Go SDK\n\x0c\n\x04lang\x12\x04\x1a\x02go\n}\n\x06source\x12s\x1aqconnection, err := sc.Connection.UpdateConnection(\n  ctx,\n  organizationId,\n  connectionId,\n  connectionConfig,\n)\n\xa4\x01*\xa1\x01\n\x13\n\x05label\x12\n\x1a\x08Java SDK\n\x0e\n\x04lang\x12\x06\x1a\x04java\nz\n\x06source\x12p\x1anConnection connection = client.connections().updateConnection(connectionId, organizationId, connectionConfig);\x82\xb5\x18\x02\x18t\xfa\xd2\xe4\x93\x02\t\x12\x07PREVIEW\x82\xd3\xe4\x93\x02\x46\x32\x38/api/v1/organizations/{organization_id}/connections/{id}:\nconnection\x12\x92\x02\n\x1b\x44\x65leteEnvironmentConnection\x12;.scalekit.v1.connections.DeleteEnvironmentConnectionRequest\x1a\x16.google.protobuf.Empty\"\x9d\x01\x92\x41Z\n\x0b\x43onnections\x12\x13\x44\x65lete a connection\x1a\x17\x44\x65lete a SSO ConnectionJ\x1d\n\x03\x32\x30\x30\x12\x16\n\x14\x44\x65leted Successfully\x82\xb5\x18\x02\x18T\xfa\xd2\xe4\x93\x02\t\x12\x07PREVIEW\x82\xd3\xe4\x93\x02%*#/api/v1/connections/{connection_id}\x12\xc0\x06\n\x10\x44\x65leteConnection\x12\x30.scalekit.v1.connections.DeleteConnectionRequest\x1a\x16.google.protobuf.Empty\"\xe1\x05\x92\x41\x88\x05\n\x0b\x43onnections\x12$Delete a connection for organization\x1a\x17\x44\x65lete a SSO ConnectionJ\x1d\n\x03\x32\x30\x30\x12\x16\n\x14\x44\x65leted Successfullyj\x9a\x04\n\rx-codeSamples\x12\x88\x04\x32\x85\x04\n\x81\x01*\x7f\n\x16\n\x05label\x12\r\x1a\x0bNode.js SDK\n\x14\n\x04lang\x12\x0c\x1a\njavascript\nO\n\x06source\x12\x45\x1a\x43\x61wait sc.connection.deleteConnection(organizationId, connectionId);\n~*|\n\x15\n\x05label\x12\x0c\x1a\nPython SDK\n\x10\n\x04lang\x12\x08\x1a\x06python\nQ\n\x06source\x12G\x1a\x45sc.connection.delete_connection(\n  organization_id,\n  connection_id\n)\n\x83\x01*\x80\x01\n\x11\n\x05label\x12\x08\x1a\x06Go SDK\n\x0c\n\x04lang\x12\x04\x1a\x02go\n]\n\x06source\x12S\x1aQerr := sc.Connection.DeleteConnection(\n  ctx,\n  organizationId,\n  connectionId,\n)\ny*w\n\x13\n\x05label\x12\n\x1a\x08Java SDK\n\x0e\n\x04lang\x12\x06\x1a\x04java\nP\n\x06source\x12\x46\x1a\x44\x63lient.connections().deleteConnection(connectionId, organizationId);\x82\xb5\x18\x02\x18t\xfa\xd2\xe4\x93\x02\t\x12\x07PREVIEW\x82\xd3\xe4\x93\x02:*8/api/v1/organizations/{organization_id}/connections/{id}\x12\xdf\x02\n\x1b\x45nableEnvironmentConnection\x12;.scalekit.v1.connections.ToggleEnvironmentConnectionRequest\x1a\x31.scalekit.v1.connections.ToggleConnectionResponse\"\xcf\x01\x92\x41\x84\x01\n\x0b\x43onnections\x12\x13\x45nable a connection\x1a\x17\x45nable a SSO ConnectionJG\n\x03\x32\x30\x30\x12@\n\x07Success\x12\x35\n3\x1a\x31.scalekit.v1.connections.ToggleConnectionResponse\x82\xb5\x18\x02\x18T\xfa\xd2\xe4\x93\x02\t\x12\x07PREVIEW\x82\xd3\xe4\x93\x02,2*/api/v1/connections/{connection_id}:enable\x12\x96\t\n\x10\x45nableConnection\x12\x30.scalekit.v1.connections.ToggleConnectionRequest\x1a\x31.scalekit.v1.connections.ToggleConnectionResponse\"\x9c\x08\x92\x41\xcb\x07\n\x0b\x43onnections\x12\x1e\x45nable organization connection\x1a\xee\x01\x41\x63tivate an existing connection for the specified organization. When enabled, users can authenticate using this connection. This endpoint changes the connection state from disabled to enabled without modifying other configuration settingsJ_\n\x03\x32\x30\x30\x12X\n\x1f\x43onnection enabled successfully\x12\x35\n3\x1a\x31.scalekit.v1.connections.ToggleConnectionResponsej\xc9\x04\n\rx-codeSamples\x12\xb7\x04\x32\xb4\x04\n\x81\x01*\x7f\n\x16\n\x05label\x12\r\x1a\x0bNode.js SDK\n\x14\n\x04lang\x12\x0c\x1a\njavascript\nO\n\x06source\x12\x45\x1a\x43\x61wait sc.connection.enableConnection(organizationId, connectionId);\n\x7f*}\n\x15\n\x05label\x12\x0c\x1a\nPython SDK\n\x10\n\x04lang\x12\x08\x1a\x06python\nR\n\x06source\x12H\x1a\x46sc.connection.enable_connection(\n  organization_id,\n  connection_id,\n)\n\x83\x01*\x80\x01\n\x11\n\x05label\x12\x08\x1a\x06Go SDK\n\x0c\n\x04lang\x12\x04\x1a\x02go\n]\n\x06source\x12S\x1aQerr := sc.Connection.EnableConnection(\n  ctx,\n  organizationId,\n  connectionId,\n)\n\xa6\x01*\xa3\x01\n\x13\n\x05label\x12\n\x1a\x08Java SDK\n\x0e\n\x04lang\x12\x06\x1a\x04java\n|\n\x06source\x12r\x1apToggleConnectionResponse response = scalekitClient.connections().enableConnection(connectionId, organizationId);\x82\xb5\x18\x02\x18t\x82\xd3\xe4\x93\x02\x41\x32?/api/v1/organizations/{organization_id}/connections/{id}:enable\x12\xe3\x02\n\x1c\x44isableEnvironmentConnection\x12;.scalekit.v1.connections.ToggleEnvironmentConnectionRequest\x1a\x31.scalekit.v1.connections.ToggleConnectionResponse\"\xd2\x01\x92\x41\x86\x01\n\x0b\x43onnections\x12\x14\x44isable a connection\x1a\x18\x44isable a SSO ConnectionJG\n\x03\x32\x30\x30\x12@\n\x07Success\x12\x35\n3\x1a\x31.scalekit.v1.connections.ToggleConnectionResponse\x82\xb5\x18\x02\x18T\xfa\xd2\xe4\x93\x02\t\x12\x07PREVIEW\x82\xd3\xe4\x93\x02-2+/api/v1/connections/{connection_id}:disable\x12\xa4\t\n\x11\x44isableConnection\x12\x30.scalekit.v1.connections.ToggleConnectionRequest\x1a\x31.scalekit.v1.connections.ToggleConnectionResponse\"\xa9\x08\x92\x41\xd7\x07\n\x0b\x43onnections\x12\x1f\x44isable organization connection\x1a\xf4\x01\x44\x65\x61\x63tivate an existing connection for the specified organization. When disabled, users cannot authenticate using this connection. This endpoint changes the connection state from enabled to disabled without modifying other configuration settingsJ`\n\x03\x32\x30\x30\x12Y\n Connection disabled successfully\x12\x35\n3\x1a\x31.scalekit.v1.connections.ToggleConnectionResponsej\xcd\x04\n\rx-codeSamples\x12\xbb\x04\x32\xb8\x04\n\x83\x01*\x80\x01\n\x16\n\x05label\x12\r\x1a\x0bNode.js SDK\n\x14\n\x04lang\x12\x0c\x1a\njavascript\nP\n\x06source\x12\x46\x1a\x44\x61wait sc.connection.disableConnection(organizationId, connectionId);\n\x7f*}\n\x15\n\x05label\x12\x0c\x1a\nPython SDK\n\x10\n\x04lang\x12\x08\x1a\x06python\nR\n\x06source\x12H\x1a\x46sc.connection.disable_connection(\n  organization_id,\n  connection_id\n)\n\x84\x01*\x81\x01\n\x11\n\x05label\x12\x08\x1a\x06Go SDK\n\x0c\n\x04lang\x12\x04\x1a\x02go\n^\n\x06source\x12T\x1aRerr := sc.Connection.DisableConnection(\n  ctx,\n  organizationId,\n  connectionId,\n)\n\xa7\x01*\xa4\x01\n\x13\n\x05label\x12\n\x1a\x08Java SDK\n\x0e\n\x04lang\x12\x06\x1a\x04java\n}\n\x06source\x12s\x1aqToggleConnectionResponse response = scalekitClient.connections().disableConnection(connectionId, organizationId);\x82\xb5\x18\x02\x18t\x82\xd3\xe4\x93\x02\x42\x32@/api/v1/organizations/{organization_id}/connections/{id}:disable\x12\x80\x03\n\x17GetConnectionTestResult\x12\x37.scalekit.v1.connections.GetConnectionTestResultRequest\x1a\x38.scalekit.v1.connections.GetConnectionTestResultResponse\"\xf1\x01\x92\x41\x8d\x01\n\x0b\x43onnections\x12\x16Test connection result\x1a\x16\x43onnection test resultJN\n\x03\x32\x30\x30\x12G\n\x07Success\x12<\n:\x1a\x38.scalekit.v1.connections.GetConnectionTestResultResponse\x82\xb5\x18\x02\x18t\xfa\xd2\xe4\x93\x02\t\x12\x07PREVIEW\x82\xd3\xe4\x93\x02\x45\x12\x43/api/v1/connections/{connection_id}/test-requests/{test_request_id}\x12\xba\x07\n\x12ListAppConnections\x12\x32.scalekit.v1.connections.ListAppConnectionsRequest\x1a\x33.scalekit.v1.connections.ListAppConnectionsResponse\"\xba\x06\x92\x41\x82\x06\n\x0b\x43onnections\x12\x14List App connections\x1a\x36Retrieves a list of app connections in the environmentJa\n\x03\x32\x30\x30\x12Z\n\"Successfully retrieved connections\x12\x34\n2\x1a\x30.scalekit.v1.connections.ListConnectionsResponsej\xc1\x04\n\rx-codeSamples\x12\xaf\x04\x32\xac\x04\n\x87\x01*\x84\x01\n\x16\n\x05label\x12\r\x1a\x0bNode.js SDK\n\x14\n\x04lang\x12\x0c\x1a\njavascript\nT\n\x06source\x12J\x1aHconst connections = await sc.connection.listConnections(organizationId);\nz*x\n\x15\n\x05label\x12\x0c\x1a\nPython SDK\n\x10\n\x04lang\x12\x08\x1a\x06python\nM\n\x06source\x12\x43\x1a\x41\x63onnections = sc.connection.list_connections(\n  organization_id\n)\n}*{\n\x11\n\x05label\x12\x08\x1a\x06Go SDK\n\x0c\n\x04lang\x12\x04\x1a\x02go\nX\n\x06source\x12N\x1aLconnections, err := sc.Connection.ListConnections(\n  ctx,\n  organizationId\n)\n\xa4\x01*\xa1\x01\n\x13\n\x05label\x12\n\x1a\x08Java SDK\n\x0e\n\x04lang\x12\x06\x1a\x04java\nz\n\x06source\x12p\x1anListConnectionsResponse response = scalekitClient.connections().listConnectionsByOrganization(organizationId);\x82\xb5\x18\x02\x18t\xfa\xd2\xe4\x93\x02\t\x12\x07PREVIEW\x82\xd3\xe4\x93\x02\x19\x12\x17/api/v1/connections/app\x1a\x9a\x01\x92\x41\x96\x01\n\x0b\x43onnections\x12\x86\x01Manage enterprise connections for your Scalekit environment. This service provides endpoints for retrieving, and updating connections.B7Z5github.com/scalekit-inc/scalekit/pkg/grpc/connectionsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'scalekit.v1.connections.connections_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z5github.com/scalekit-inc/scalekit/pkg/grpc/connections'
  _globals['_ASSIGNDOMAINSTOCONNECTIONREQUEST'].fields_by_name['organization_id']._loaded_options = None
  _globals['_ASSIGNDOMAINSTOCONNECTIONREQUEST'].fields_by_name['organization_id']._serialized_options = b'\272H\017r\n\020\001\030 :\004org_\310\001\001'
  _globals['_ASSIGNDOMAINSTOCONNECTIONREQUEST'].fields_by_name['connection_id']._loaded_options = None
  _globals['_ASSIGNDOMAINSTOCONNECTIONREQUEST'].fields_by_name['connection_id']._serialized_options = b'\272H\020r\013\020\001\030 :\005conn_\310\001\001'
  _globals['_ASSIGNDOMAINSTOCONNECTIONREQUEST'].fields_by_name['domain_ids']._loaded_options = None
  _globals['_ASSIGNDOMAINSTOCONNECTIONREQUEST'].fields_by_name['domain_ids']._serialized_options = b'\272H\007\222\001\004\010\000\0202'
  _globals['_ASSIGNDOMAINSTOCONNECTIONRESPONSE'].fields_by_name['connection']._loaded_options = None
  _globals['_ASSIGNDOMAINSTOCONNECTIONRESPONSE'].fields_by_name['connection']._serialized_options = b'\222A\366\0022 Connection with assigned domainsJ\321\002{\n  \"id\": \"conn_1234567890\",\n  \"provider\": \"OKTA\",\n  \"type\": \"OIDC\",\n  \"status\": \"CONFIGURED\",\n  \"enabled\": true,\n  \"debug_enabled\": false,\n  \"organization_id\": \"org_1234567890\",\n  \"ui_button_title\": \"Login with SSO\",\n  \"configuration_type\": \"MANUAL\",\n  \"test_connection_uri\": \"https://auth.example.com/test-connection/conn_1234567890\"\n}'
  _globals['_PROVIDER'].fields_by_name['key_id']._loaded_options = None
  _globals['_PROVIDER'].fields_by_name['key_id']._serialized_options = b'\222A\0332\017Provider Key IDJ\010\"google\"'
  _globals['_PROVIDER'].fields_by_name['display_name']._loaded_options = None
  _globals['_PROVIDER'].fields_by_name['display_name']._serialized_options = b'\222A!2\025Provider Display NameJ\010\"Google\"'
  _globals['_PROVIDER'].fields_by_name['description']._loaded_options = None
  _globals['_PROVIDER'].fields_by_name['description']._serialized_options = b'\222A-2\024Provider DescriptionJ\025\"Sign In With Google\"'
  _globals['_CREATEENVIRONMENTCONNECTIONREQUEST'].fields_by_name['connection']._loaded_options = None
  _globals['_CREATEENVIRONMENTCONNECTIONREQUEST'].fields_by_name['connection']._serialized_options = b'\272H\003\310\001\001'
  _globals['_CREATEENVIRONMENTCONNECTIONREQUEST'].fields_by_name['flags']._loaded_options = None
  _globals['_CREATEENVIRONMENTCONNECTIONREQUEST'].fields_by_name['flags']._serialized_options = b'\222Al2SOptional flags to control connection creation behavior, such as enabling debug modeJ\025{ \"is_social\": true }'
  _globals['_CREATECONNECTIONREQUEST'].fields_by_name['organization_id']._loaded_options = None
  _globals['_CREATECONNECTIONREQUEST'].fields_by_name['organization_id']._serialized_options = b'\222Ae2JUnique identifier of the organization for which the connection is created.J\027\"org_12362474900684814\"\272H\006r\004\020\001\030 '
  _globals['_CREATECONNECTIONREQUEST'].fields_by_name['connection']._loaded_options = None
  _globals['_CREATECONNECTIONREQUEST'].fields_by_name['connection']._serialized_options = b'\272H\003\310\001\001'
  _globals['_CREATECONNECTION'].fields_by_name['provider']._loaded_options = None
  _globals['_CREATECONNECTION'].fields_by_name['provider']._serialized_options = b'\222Av2lIdentity provider service that handles authentication (such as OKTA, Google, Azure AD, or a custom provider)J\006\"OKTA\"\272H\005\202\001\002\020\001'
  _globals['_CREATECONNECTION'].fields_by_name['type']._loaded_options = None
  _globals['_CREATECONNECTION'].fields_by_name['type']._serialized_options = b'\272H\005\202\001\002\020\001'
  _globals['_CREATECONNECTION'].fields_by_name['provider_key']._loaded_options = None
  _globals['_CREATECONNECTION'].fields_by_name['provider_key']._serialized_options = b'\222Ar2fKey ID of the identity provider. This is used to identify the specific configuration for the provider.J\010\"google\"'
  _globals['_CONNECTION_ATTRIBUTEMAPPINGENTRY']._loaded_options = None
  _globals['_CONNECTION_ATTRIBUTEMAPPINGENTRY']._serialized_options = b'8\001'
  _globals['_CONNECTION'].fields_by_name['id']._loaded_options = None
  _globals['_CONNECTION'].fields_by_name['id']._serialized_options = b'\222Az2_Unique identifier for this connection. Used in API calls to reference this specific connection.J\027\"conn_2123312131125533\"'
  _globals['_CONNECTION'].fields_by_name['provider']._loaded_options = None
  _globals['_CONNECTION'].fields_by_name['provider']._serialized_options = b'\222Av2lIdentity provider service that handles authentication (such as OKTA, Google, Azure AD, or a custom provider)J\006\"OKTA\"'
  _globals['_CONNECTION'].fields_by_name['type']._loaded_options = None
  _globals['_CONNECTION'].fields_by_name['type']._serialized_options = b'\222At2jAuthentication protocol used by this connection. Can be OIDC (OpenID Connect), SAML, OAUTH, or MAGIC_LINK.J\006\"OIDC\"'
  _globals['_CONNECTION'].fields_by_name['status']._loaded_options = None
  _globals['_CONNECTION'].fields_by_name['status']._serialized_options = b'\222A|2kCurrent configuration status of the connection. Possible values include IN_PROGRESS, CONFIGURED, and ERROR.J\r\"IN_PROGRESS\"\340A\003'
  _globals['_CONNECTION'].fields_by_name['enabled']._loaded_options = None
  _globals['_CONNECTION'].fields_by_name['enabled']._serialized_options = b'\222A\214\0012\202\001Controls whether users can sign in using this connection. When false, the connection exists but cannot be used for authentication.J\005false'
  _globals['_CONNECTION'].fields_by_name['debug_enabled']._loaded_options = None
  _globals['_CONNECTION'].fields_by_name['debug_enabled']._serialized_options = b'\222A\206\0012~Enables testing mode that allows non-HTTPS endpoints. Should only be enabled in development environments, never in production.J\004true'
  _globals['_CONNECTION'].fields_by_name['organization_id']._loaded_options = None
  _globals['_CONNECTION'].fields_by_name['organization_id']._serialized_options = b'\222A\216\0012tIdentifier of the organization that owns this connection. Connections are typically scoped to a single organization.J\026\"org_2123312131125533\"'
  _globals['_CONNECTION'].fields_by_name['ui_button_title']._loaded_options = None
  _globals['_CONNECTION'].fields_by_name['ui_button_title']._serialized_options = b'\222A\201\0012mCustom text shown on the login button in the user interface. Helps users identify which SSO option to select.J\020\"Login with SSO\"\372\322\344\223\002\t\022\007PREVIEW'
  _globals['_CONNECTION'].fields_by_name['configuration_type']._loaded_options = None
  _globals['_CONNECTION'].fields_by_name['configuration_type']._serialized_options = b'\222Aw2kHow the connection was configured: DISCOVERY (automatic configuration) or MANUAL (administrator configured)J\010\"MANUAL\"'
  _globals['_CONNECTION'].fields_by_name['test_connection_uri']._loaded_options = None
  _globals['_CONNECTION'].fields_by_name['test_connection_uri']._serialized_options = b'\222A\252\0012fURI that can be used to test this connection. Visit this URL to verify the connection works correctly.J@\"https://auth.example.com/test-connection/conn_2123312131125533\"'
  _globals['_CONNECTION'].fields_by_name['attribute_mapping']._loaded_options = None
  _globals['_CONNECTION'].fields_by_name['attribute_mapping']._serialized_options = b'\222A|2zMaps identity provider attributes to user profile fields. For example, {\'email\': \'user.mail\', \'name\': \'user.displayName\'}.\272H\026\232\001\023\020\036\"\006r\004\020\001\030d*\007r\005\020\001\030\200\002'
  _globals['_CONNECTION'].fields_by_name['create_time']._loaded_options = None
  _globals['_CONNECTION'].fields_by_name['create_time']._serialized_options = b'\222A_2EWhen this connection was first created. Format is RFC 3339 timestamp.J\026\"2023-01-15T14:30:00Z\"\340A\003\372\322\344\223\002\t\022\007PREVIEW'
  _globals['_CONNECTION'].fields_by_name['update_time']._loaded_options = None
  _globals['_CONNECTION'].fields_by_name['update_time']._serialized_options = b'\222A_2EWhen this connection was last modified. Format is RFC 3339 timestamp.J\026\"2023-02-20T09:15:30Z\"\340A\003\372\322\344\223\002\t\022\007PREVIEW'
  _globals['_CONNECTION'].fields_by_name['oidc_config']._loaded_options = None
  _globals['_CONNECTION'].fields_by_name['oidc_config']._serialized_options = b'\222A^2\\Configuration details for OpenID Connect (OIDC) connections. Present only when type is OIDC.'
  _globals['_CONNECTION'].fields_by_name['saml_config']._loaded_options = None
  _globals['_CONNECTION'].fields_by_name['saml_config']._serialized_options = b'\222AM2KConfiguration details for SAML connections. Present only when type is SAML.'
  _globals['_CONNECTION'].fields_by_name['oauth_config']._loaded_options = None
  _globals['_CONNECTION'].fields_by_name['oauth_config']._serialized_options = b'\222AO2MConfiguration details for OAuth connections. Present only when type is OAUTH.'
  _globals['_CONNECTION'].fields_by_name['passwordless_config']._loaded_options = None
  _globals['_CONNECTION'].fields_by_name['passwordless_config']._serialized_options = b'\222A\\2ZConfiguration details for Magic Link authentication. Present only when type is MAGIC_LINK.'
  _globals['_CONNECTION'].fields_by_name['static_config']._loaded_options = None
  _globals['_CONNECTION'].fields_by_name['static_config']._serialized_options = b'\222Ak2iStatic configuration for custom connections. Present only when type is BASIC, BEARER, API_KEY, or custom.'
  _globals['_CONNECTION'].fields_by_name['key_id']._loaded_options = None
  _globals['_CONNECTION'].fields_by_name['key_id']._serialized_options = b'\222A^2\\Alternative identifier for this connection, typically used in frontend applications or URLs.'
  _globals['_CONNECTION'].fields_by_name['provider_key']._loaded_options = None
  _globals['_CONNECTION'].fields_by_name['provider_key']._serialized_options = b'\222AO2CKey ID of the identity provider service that handles authenticationJ\010\"google\"'
  _globals['_CONNECTION'].fields_by_name['domains']._loaded_options = None
  _globals['_CONNECTION'].fields_by_name['domains']._serialized_options = b'\222Ap2SDomain associated with this connection, used for domain-based authentication flows.J\031[{\"name\": \"example.com\"}]'
  _globals['_CREATECONNECTIONRESPONSE'].fields_by_name['connection']._loaded_options = None
  _globals['_CREATECONNECTIONRESPONSE'].fields_by_name['connection']._serialized_options = b'\222A\0232\021Connection Detail'
  _globals['_UPDATEENVIRONMENTCONNECTIONREQUEST'].fields_by_name['connection_id']._loaded_options = None
  _globals['_UPDATEENVIRONMENTCONNECTIONREQUEST'].fields_by_name['connection_id']._serialized_options = b'\222AM2+Connection ID. Unique ID for the connectionJ\026\"conn_121312434123312\"\312>\005\372\002\002id\272H\006r\004\020\001\030 '
  _globals['_UPDATEENVIRONMENTCONNECTIONREQUEST'].fields_by_name['connection']._loaded_options = None
  _globals['_UPDATEENVIRONMENTCONNECTIONREQUEST'].fields_by_name['connection']._serialized_options = b'\222A-2#Connection properties to be updated\312>\005\372\002\002id\272H\003\310\001\001'
  _globals['_UPDATECONNECTIONREQUEST'].fields_by_name['organization_id']._loaded_options = None
  _globals['_UPDATECONNECTIONREQUEST'].fields_by_name['organization_id']._serialized_options = b'\222A<2#Organization ID for the Connection.J\025\"org_121312434123312\"\272H\006r\004\020\001\030 '
  _globals['_UPDATECONNECTIONREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_UPDATECONNECTIONREQUEST'].fields_by_name['id']._serialized_options = b'\222AE2+Connection ID. Unique ID for the connectionJ\026\"conn_121312434123312\"\272H\006r\004\020\001\030 '
  _globals['_UPDATECONNECTIONREQUEST'].fields_by_name['connection']._loaded_options = None
  _globals['_UPDATECONNECTIONREQUEST'].fields_by_name['connection']._serialized_options = b'\222A-2#Connection properties to be updated\312>\005\372\002\002id\272H\003\310\001\001'
  _globals['_UPDATECONNECTION_ATTRIBUTEMAPPINGENTRY']._loaded_options = None
  _globals['_UPDATECONNECTION_ATTRIBUTEMAPPINGENTRY']._serialized_options = b'8\001'
  _globals['_UPDATECONNECTION'].fields_by_name['provider']._loaded_options = None
  _globals['_UPDATECONNECTION'].fields_by_name['provider']._serialized_options = b'\222A#2\027SSO Connection ProviderJ\010\"CUSTOM\"\272H\005\202\001\002\020\001'
  _globals['_UPDATECONNECTION'].fields_by_name['type']._loaded_options = None
  _globals['_UPDATECONNECTION'].fields_by_name['type']._serialized_options = b'\222A*2 Connection Protocol OIDC / SAML J\006\"OIDC\"\272H\005\202\001\002\020\001'
  _globals['_UPDATECONNECTION'].fields_by_name['debug_enabled']._loaded_options = None
  _globals['_UPDATECONNECTION'].fields_by_name['debug_enabled']._serialized_options = b'\222Aj2bDebug mode for the connection. Debug would allow non HTTPS endpoint to be used with the connectionJ\004true'
  _globals['_UPDATECONNECTION'].fields_by_name['ui_button_title']._loaded_options = None
  _globals['_UPDATECONNECTION'].fields_by_name['ui_button_title']._serialized_options = b'\222A52!Display name for the Login ButtonJ\020\"Login with SSO\"\372\322\344\223\002\t\022\007PREVIEW'
  _globals['_UPDATECONNECTION'].fields_by_name['configuration_type']._loaded_options = None
  _globals['_UPDATECONNECTION'].fields_by_name['configuration_type']._serialized_options = b'\222A 2\024Configuration Type. J\010\"MANUAL\"'
  _globals['_UPDATECONNECTION'].fields_by_name['attribute_mapping']._loaded_options = None
  _globals['_UPDATECONNECTION'].fields_by_name['attribute_mapping']._serialized_options = b'\222A\0232\021Attribute Mapping\272H\026\232\001\023\020\036\"\006r\004\020\001\030d*\007r\005\020\001\030\200\002'
  _globals['_UPDATECONNECTION'].fields_by_name['oidc_config']._loaded_options = None
  _globals['_UPDATECONNECTION'].fields_by_name['oidc_config']._serialized_options = b'\222A.2,OIDC Configuration if ConnectionType == OIDC'
  _globals['_UPDATECONNECTION'].fields_by_name['saml_config']._loaded_options = None
  _globals['_UPDATECONNECTION'].fields_by_name['saml_config']._serialized_options = b'\222A.2,SAML Configuration if ConnectionType == SAML'
  _globals['_UPDATECONNECTION'].fields_by_name['oauth_config']._loaded_options = None
  _globals['_UPDATECONNECTION'].fields_by_name['oauth_config']._serialized_options = b'\222A02.OAuth Configuration if ConnectionType == OAUTH'
  _globals['_UPDATECONNECTION'].fields_by_name['passwordless_config']._loaded_options = None
  _globals['_UPDATECONNECTION'].fields_by_name['passwordless_config']._serialized_options = b'\222A:28Magic Link Configuration if ConnectionType == MAGIC_LINK'
  _globals['_UPDATECONNECTION'].fields_by_name['key_id']._loaded_options = None
  _globals['_UPDATECONNECTION'].fields_by_name['key_id']._serialized_options = b'\272H\006r\004\020\001\030 '
  _globals['_UPDATECONNECTION'].fields_by_name['provider_key']._loaded_options = None
  _globals['_UPDATECONNECTION'].fields_by_name['provider_key']._serialized_options = b'\222AO2CKey ID of the identity provider service that handles authenticationJ\010\"google\"'
  _globals['_UPDATECONNECTIONRESPONSE'].fields_by_name['connection']._loaded_options = None
  _globals['_UPDATECONNECTIONRESPONSE'].fields_by_name['connection']._serialized_options = b'\222A\0342\032Updated Connection details'
  _globals['_DELETEENVIRONMENTCONNECTIONREQUEST'].fields_by_name['connection_id']._loaded_options = None
  _globals['_DELETEENVIRONMENTCONNECTIONREQUEST'].fields_by_name['connection_id']._serialized_options = b'\222AE2+Connection ID. Unique ID for the connectionJ\026\"conn_121312434123312\"\272H\006r\004\020\001\030 '
  _globals['_DELETECONNECTIONREQUEST'].fields_by_name['organization_id']._loaded_options = None
  _globals['_DELETECONNECTIONREQUEST'].fields_by_name['organization_id']._serialized_options = b'\222A<2#Organization ID for the Connection.J\025\"org_121312434123312\"\272H\006r\004\020\001\030 '
  _globals['_DELETECONNECTIONREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_DELETECONNECTIONREQUEST'].fields_by_name['id']._serialized_options = b'\222AE2+Connection ID. Unique ID for the connectionJ\026\"conn_121312434123312\"\272H\006r\004\020\001\030 '
  _globals['_GETENVIRONMENTCONNECTIONREQUEST'].fields_by_name['connection_id']._loaded_options = None
  _globals['_GETENVIRONMENTCONNECTIONREQUEST'].fields_by_name['connection_id']._serialized_options = b'\222A>2$Unique identifier for the ConnectionJ\026\"conn_121312434123312\"\272H\006r\004\020\001\030 '
  _globals['_GETCONNECTIONREQUEST'].fields_by_name['organization_id']._loaded_options = None
  _globals['_GETCONNECTIONREQUEST'].fields_by_name['organization_id']._serialized_options = b'\222A\203\0012jOrganization identifier (required). Specifies which organization owns the connection you want to retrieve.J\025\"org_121312434123312\"\272H\006r\004\020\001\030 '
  _globals['_GETCONNECTIONREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_GETCONNECTIONREQUEST'].fields_by_name['id']._serialized_options = b'\222A\202\0012hConnection identifier (required). Specifies which specific connection to retrieve from the organization.J\026\"conn_121312434123312\"\272H\006r\004\020\001\030 '
  _globals['_GETCONNECTIONRESPONSE'].fields_by_name['connection']._loaded_options = None
  _globals['_GETCONNECTIONRESPONSE'].fields_by_name['connection']._serialized_options = b'\222A\266\0012\263\001Complete connection details including provider configuration, protocol settings, status, and all metadata. Contains everything needed to understand the connection\'s current state.'
  _globals['_LISTCONNECTIONSREQUEST'].fields_by_name['organization_id']._loaded_options = None
  _globals['_LISTCONNECTIONSREQUEST'].fields_by_name['organization_id']._serialized_options = b'\222AF2-Filter connections by organization identifierJ\025\"org_121312434123312\"\272H\006r\004\020\001\030 '
  _globals['_LISTCONNECTIONSREQUEST'].fields_by_name['domain']._loaded_options = None
  _globals['_LISTCONNECTIONSREQUEST'].fields_by_name['domain']._serialized_options = b'\222AV2CFilter connections by email domain associated with the organizationJ\017\"hero-saas.app\"\272H\006r\004\020\001\030 '
  _globals['_LISTCONNECTIONSREQUEST'].fields_by_name['include']._loaded_options = None
  _globals['_LISTCONNECTIONSREQUEST'].fields_by_name['include']._serialized_options = b'\222A\242\0012\237\001Filter connections by status. Use \'all\' to include all connections regardless of status. Default behavior shows only active (completed and enabled) connections'
  _globals['_LISTCONNECTIONSRESPONSE'].fields_by_name['connections']._loaded_options = None
  _globals['_LISTCONNECTIONSRESPONSE'].fields_by_name['connections']._serialized_options = b'\222A321List of connections matching the request criteria'
  _globals['_LISTCONNECTION'].fields_by_name['id']._loaded_options = None
  _globals['_LISTCONNECTION'].fields_by_name['id']._serialized_options = b'\222A>2#Unique identifier of the connectionJ\027\"conn_2123312131125533\"'
  _globals['_LISTCONNECTION'].fields_by_name['provider']._loaded_options = None
  _globals['_LISTCONNECTION'].fields_by_name['provider']._serialized_options = b'\222AA25Identity provider type (e.g., OKTA, Google, Azure AD)J\010\"CUSTOM\"'
  _globals['_LISTCONNECTION'].fields_by_name['type']._loaded_options = None
  _globals['_LISTCONNECTION'].fields_by_name['type']._serialized_options = b'\222A82.Authentication protocol used by the connectionJ\006\"OIDC\"'
  _globals['_LISTCONNECTION'].fields_by_name['status']._loaded_options = None
  _globals['_LISTCONNECTION'].fields_by_name['status']._serialized_options = b'\222A?2.Current configuration status of the connectionJ\r\"IN_PROGRESS\"\340A\003'
  _globals['_LISTCONNECTION'].fields_by_name['enabled']._loaded_options = None
  _globals['_LISTCONNECTION'].fields_by_name['enabled']._serialized_options = b'\222AJ2AWhether the connection is currently active for organization usersJ\005false'
  _globals['_LISTCONNECTION'].fields_by_name['organization_id']._loaded_options = None
  _globals['_LISTCONNECTION'].fields_by_name['organization_id']._serialized_options = b'\222AY2?Unique identifier of the organization that owns this connectionJ\026\"org_2123312131125533\"'
  _globals['_LISTCONNECTION'].fields_by_name['ui_button_title']._loaded_options = None
  _globals['_LISTCONNECTION'].fields_by_name['ui_button_title']._serialized_options = b'\222AN2:Text displayed on the SSO login button for this connectionJ\020\"Login with SSO\"\372\322\344\223\002\t\022\007PREVIEW'
  _globals['_LISTCONNECTION'].fields_by_name['domains']._loaded_options = None
  _globals['_LISTCONNECTION'].fields_by_name['domains']._serialized_options = b'\222AW2/List of domains configured with this connectionJ$[\"yourapp.com\", \"yourworkspace.com\"]'
  _globals['_LISTCONNECTION'].fields_by_name['organization_name']._loaded_options = None
  _globals['_LISTCONNECTION'].fields_by_name['organization_name']._serialized_options = b'\222AA2*Name of the organization of the connectionJ\023\"Your Organization\"'
  _globals['_LISTCONNECTION'].fields_by_name['provider_key']._loaded_options = None
  _globals['_LISTCONNECTION'].fields_by_name['provider_key']._serialized_options = b'\222AO2CKey ID of the identity provider service that handles authenticationJ\010\"google\"'
  _globals['_LISTCONNECTION'].fields_by_name['key_id']._loaded_options = None
  _globals['_LISTCONNECTION'].fields_by_name['key_id']._serialized_options = b'\222Av2[Alternative identifier for this connection, typically used in frontend applications or URLsJ\027\"conn_2123312131125533\"'
  _globals['_LISTCONNECTION'].fields_by_name['created_at']._loaded_options = None
  _globals['_LISTCONNECTION'].fields_by_name['created_at']._serialized_options = b'\222A@2&When this connection was first createdJ\026\"2023-01-15T14:30:00Z\"\340A\003\372\322\344\223\002\t\022\007PREVIEW'
  _globals['_LISTORGANIZATIONCONNECTIONSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTORGANIZATIONCONNECTIONSREQUEST'].fields_by_name['page_size']._serialized_options = b'\222AY2SMaximum number of organizations to return per page. Value must be between 1 and 30.J\00230\272H\004*\002\030\036'
  _globals['_LISTORGANIZATIONCONNECTIONSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTORGANIZATIONCONNECTIONSREQUEST'].fields_by_name['page_token']._serialized_options = b'\222A\201\0012aToken from a previous response for pagination. Provide this to retrieve the next page of results.J\034eyJwYWdlIjoyLCJsaW1pdCI6MzB9'
  _globals['_LISTORGANIZATIONCONNECTIONSRESPONSE'].fields_by_name['connections']._loaded_options = None
  _globals['_LISTORGANIZATIONCONNECTIONSRESPONSE'].fields_by_name['connections']._serialized_options = b'\222A220List of connections matching the filter criteria'
  _globals['_SEARCHORGANIZATIONCONNECTIONSREQUEST'].fields_by_name['query']._loaded_options = None
  _globals['_SEARCHORGANIZATIONCONNECTIONSREQUEST'].fields_by_name['query']._serialized_options = b'\222AG2-Search query Connection ID or Organization IDJ\026\"conn_121312434123312\"\272H\004r\002\030d'
  _globals['_SEARCHORGANIZATIONCONNECTIONSREQUEST'].fields_by_name['provider']._loaded_options = None
  _globals['_SEARCHORGANIZATIONCONNECTIONSREQUEST'].fields_by_name['provider']._serialized_options = b'\222A\0342\022Filter by providerJ\006\"OKTA\"'
  _globals['_SEARCHORGANIZATIONCONNECTIONSREQUEST'].fields_by_name['status']._loaded_options = None
  _globals['_SEARCHORGANIZATIONCONNECTIONSREQUEST'].fields_by_name['status']._serialized_options = b'\222A*2\033Filter by connection statusJ\013\"COMPLETED\"\272H\005\202\001\002\020\001'
  _globals['_SEARCHORGANIZATIONCONNECTIONSREQUEST'].fields_by_name['connection_type']._loaded_options = None
  _globals['_SEARCHORGANIZATIONCONNECTIONSREQUEST'].fields_by_name['connection_type']._serialized_options = b'\222A*2\033Filter by connection statusJ\013\"COMPLETED\"\272H\005\202\001\002\020\001'
  _globals['_SEARCHORGANIZATIONCONNECTIONSREQUEST'].fields_by_name['enabled']._loaded_options = None
  _globals['_SEARCHORGANIZATIONCONNECTIONSREQUEST'].fields_by_name['enabled']._serialized_options = b'\222A-2#Filter by connection enabled statusJ\006\"true\"'
  _globals['_SEARCHORGANIZATIONCONNECTIONSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_SEARCHORGANIZATIONCONNECTIONSREQUEST'].fields_by_name['page_size']._serialized_options = b'\222AY2SMaximum number of organizations to return per page. Value must be between 1 and 30.J\00230\272H\004*\002\030\036'
  _globals['_SEARCHORGANIZATIONCONNECTIONSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_SEARCHORGANIZATIONCONNECTIONSREQUEST'].fields_by_name['page_token']._serialized_options = b'\222A\201\0012aToken from a previous response for pagination. Provide this to retrieve the next page of results.J\034eyJwYWdlIjoyLCJsaW1pdCI6MzB9'
  _globals['_SEARCHORGANIZATIONCONNECTIONSRESPONSE'].fields_by_name['connections']._loaded_options = None
  _globals['_SEARCHORGANIZATIONCONNECTIONSRESPONSE'].fields_by_name['connections']._serialized_options = b'\222A220List of connections matching the filter criteria'
  _globals['_TOGGLEENVIRONMENTCONNECTIONREQUEST'].fields_by_name['connection_id']._loaded_options = None
  _globals['_TOGGLEENVIRONMENTCONNECTIONREQUEST'].fields_by_name['connection_id']._serialized_options = b'\222AE2+Connection ID. Unique ID for the connectionJ\026\"conn_121312434123312\"\272H\006r\004\020\001\030 '
  _globals['_TOGGLECONNECTIONREQUEST'].fields_by_name['organization_id']._loaded_options = None
  _globals['_TOGGLECONNECTIONREQUEST'].fields_by_name['organization_id']._serialized_options = b'\222A]2DUnique identifier of the organization associated with the connectionJ\025\"org_121312434123312\"\272H\006r\004\020\001\030 '
  _globals['_TOGGLECONNECTIONREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_TOGGLECONNECTIONREQUEST'].fields_by_name['id']._serialized_options = b'\222AL22Unique identifier for the connection to be toggledJ\026\"conn_121312434123312\"\272H\006r\004\020\001\030 '
  _globals['_TOGGLECONNECTIONRESPONSE'].fields_by_name['enabled']._loaded_options = None
  _globals['_TOGGLECONNECTIONRESPONSE'].fields_by_name['enabled']._serialized_options = b'\222A\212\0012\201\001Current state of the connection after the operation. True means the connection is now enabled and can be used for authentication.J\004true'
  _globals['_TOGGLECONNECTIONRESPONSE'].fields_by_name['error_message']._loaded_options = None
  _globals['_TOGGLECONNECTIONRESPONSE'].fields_by_name['error_message']._serialized_options = b'\222A52$Error message if the operation failsJ\r\"placeholder\"'
  _globals['_OIDCCONNECTIONCONFIG'].fields_by_name['issuer']._loaded_options = None
  _globals['_OIDCCONNECTIONCONFIG'].fields_by_name['issuer']._serialized_options = b'\222A12\nIssuer URLJ#\"https://youridp.com/service/oauth\"'
  _globals['_OIDCCONNECTIONCONFIG'].fields_by_name['discovery_endpoint']._loaded_options = None
  _globals['_OIDCCONNECTIONCONFIG'].fields_by_name['discovery_endpoint']._serialized_options = b'\222AZ2\022Discovery EndpointJD\"https://youridp.com/service/oauth/.well-known/openid-configuration\"'
  _globals['_OIDCCONNECTIONCONFIG'].fields_by_name['authorize_uri']._loaded_options = None
  _globals['_OIDCCONNECTIONCONFIG'].fields_by_name['authorize_uri']._serialized_options = b'\222A>2\rAuthorize URIJ-\"https://youridp.com/service/oauth/authorize\"'
  _globals['_OIDCCONNECTIONCONFIG'].fields_by_name['token_uri']._loaded_options = None
  _globals['_OIDCCONNECTIONCONFIG'].fields_by_name['token_uri']._serialized_options = b'\222A62\tToken URIJ)\"https://youridp.com/service/oauth/token\"'
  _globals['_OIDCCONNECTIONCONFIG'].fields_by_name['user_info_uri']._loaded_options = None
  _globals['_OIDCCONNECTIONCONFIG'].fields_by_name['user_info_uri']._serialized_options = b'\222A=2\rUser Info URIJ,\"https://youridp.com/service/oauth/userinfo\"'
  _globals['_OIDCCONNECTIONCONFIG'].fields_by_name['jwks_uri']._loaded_options = None
  _globals['_OIDCCONNECTIONCONFIG'].fields_by_name['jwks_uri']._serialized_options = b'\222A42\010JWKS URIJ(\"https://youridp.com/service/oauth/jwks\"'
  _globals['_OIDCCONNECTIONCONFIG'].fields_by_name['client_id']._loaded_options = None
  _globals['_OIDCCONNECTIONCONFIG'].fields_by_name['client_id']._serialized_options = b'\222A\0362\tClient IDJ\021\"oauth_client_id\"'
  _globals['_OIDCCONNECTIONCONFIG'].fields_by_name['client_secret']._loaded_options = None
  _globals['_OIDCCONNECTIONCONFIG'].fields_by_name['client_secret']._serialized_options = b'\222A&2\rClient SecretJ\025\"oauth_client_secret\"'
  _globals['_OIDCCONNECTIONCONFIG'].fields_by_name['scopes']._loaded_options = None
  _globals['_OIDCCONNECTIONCONFIG'].fields_by_name['scopes']._serialized_options = b'\222A$2\013OIDC ScopesJ\025[\"openid\", \"profile\"]'
  _globals['_OIDCCONNECTIONCONFIG'].fields_by_name['token_auth_type']._loaded_options = None
  _globals['_OIDCCONNECTIONCONFIG'].fields_by_name['token_auth_type']._serialized_options = b'\222A\0372\017Token Auth TypeJ\014\"URL_PARAMS\"'
  _globals['_OIDCCONNECTIONCONFIG'].fields_by_name['redirect_uri']._loaded_options = None
  _globals['_OIDCCONNECTIONCONFIG'].fields_by_name['redirect_uri']._serialized_options = b'\222AD2\014Redirect URIJ4\"https://yourapp.com/sso/v1/oidc/conn_1234/callback\"'
  _globals['_OIDCCONNECTIONCONFIG'].fields_by_name['pkce_enabled']._loaded_options = None
  _globals['_OIDCCONNECTIONCONFIG'].fields_by_name['pkce_enabled']._serialized_options = b'\222A\0242\014PKCE EnabledJ\004true'
  _globals['_OIDCCONNECTIONCONFIG'].fields_by_name['idp_logout_required']._loaded_options = None
  _globals['_OIDCCONNECTIONCONFIG'].fields_by_name['idp_logout_required']._serialized_options = b'\222A\0312\021Enable IDP logoutJ\004true'
  _globals['_OIDCCONNECTIONCONFIG'].fields_by_name['post_logout_redirect_uri']._loaded_options = None
  _globals['_OIDCCONNECTIONCONFIG'].fields_by_name['post_logout_redirect_uri']._serialized_options = b'\222AW2\030post logout redirect uriJ;\"https://yourapp.com/sso/v1/oidc/conn_1234/logout/callback\"\340A\003'
  _globals['_OIDCCONNECTIONCONFIG'].fields_by_name['backchannel_logout_redirect_uri']._loaded_options = None
  _globals['_OIDCCONNECTIONCONFIG'].fields_by_name['backchannel_logout_redirect_uri']._serialized_options = b'\222A~2<backchannel logout redirect uri where idp sends logout_tokenJ>\"https://yourapp.com/sso/v1/oidc/conn_1234/backchannel-logout\"\340A\003'
  _globals['_OAUTHCONNECTIONCONFIG'].fields_by_name['authorize_uri']._loaded_options = None
  _globals['_OAUTHCONNECTIONCONFIG'].fields_by_name['authorize_uri']._serialized_options = b'\222A>2\rAuthorize URIJ-\"https://youridp.com/service/oauth/authorize\"'
  _globals['_OAUTHCONNECTIONCONFIG'].fields_by_name['token_uri']._loaded_options = None
  _globals['_OAUTHCONNECTIONCONFIG'].fields_by_name['token_uri']._serialized_options = b'\222A62\tToken URIJ)\"https://youridp.com/service/oauth/token\"'
  _globals['_OAUTHCONNECTIONCONFIG'].fields_by_name['user_info_uri']._loaded_options = None
  _globals['_OAUTHCONNECTIONCONFIG'].fields_by_name['user_info_uri']._serialized_options = b'\222A=2\rUser Info URIJ,\"https://youridp.com/service/oauth/userinfo\"'
  _globals['_OAUTHCONNECTIONCONFIG'].fields_by_name['client_id']._loaded_options = None
  _globals['_OAUTHCONNECTIONCONFIG'].fields_by_name['client_id']._serialized_options = b'\222A\0362\tClient IDJ\021\"oauth_client_id\"'
  _globals['_OAUTHCONNECTIONCONFIG'].fields_by_name['client_secret']._loaded_options = None
  _globals['_OAUTHCONNECTIONCONFIG'].fields_by_name['client_secret']._serialized_options = b'\222A&2\rClient SecretJ\025\"oauth_client_secret\"'
  _globals['_OAUTHCONNECTIONCONFIG'].fields_by_name['scopes']._loaded_options = None
  _globals['_OAUTHCONNECTIONCONFIG'].fields_by_name['scopes']._serialized_options = b'\222A$2\013OIDC ScopesJ\025[\"openid\", \"profile\"]'
  _globals['_OAUTHCONNECTIONCONFIG'].fields_by_name['redirect_uri']._loaded_options = None
  _globals['_OAUTHCONNECTIONCONFIG'].fields_by_name['redirect_uri']._serialized_options = b'\222A<2\014Redirect URIJ,\"https://yourapp.com/service/oauth/redirect\"'
  _globals['_OAUTHCONNECTIONCONFIG'].fields_by_name['pkce_enabled']._loaded_options = None
  _globals['_OAUTHCONNECTIONCONFIG'].fields_by_name['pkce_enabled']._serialized_options = b'\222A\0242\014PKCE EnabledJ\004true'
  _globals['_OAUTHCONNECTIONCONFIG'].fields_by_name['prompt']._loaded_options = None
  _globals['_OAUTHCONNECTIONCONFIG'].fields_by_name['prompt']._serialized_options = b'\222A\0352\023Prompt for the userJ\006\"none\"'
  _globals['_OAUTHCONNECTIONCONFIG'].fields_by_name['use_platform_creds']._loaded_options = None
  _globals['_OAUTHCONNECTIONCONFIG'].fields_by_name['use_platform_creds']._serialized_options = b'\222A 2\030Use Scalekit credentialsJ\004true'
  _globals['_OAUTHCONNECTIONCONFIG'].fields_by_name['access_type']._loaded_options = None
  _globals['_OAUTHCONNECTIONCONFIG'].fields_by_name['access_type']._serialized_options = b'\222A\0302\013Access TypeJ\t\"offline\"'
  _globals['_PASSWORDLESSCONFIG'].fields_by_name['type']._loaded_options = None
  _globals['_PASSWORDLESSCONFIG'].fields_by_name['type']._serialized_options = b'\222A\0332\021Passwordless TypeJ\006\"LINK\"'
  _globals['_PASSWORDLESSCONFIG'].fields_by_name['frequency']._loaded_options = None
  _globals['_PASSWORDLESSCONFIG'].fields_by_name['frequency']._serialized_options = b'\222A\0232\016Link FrequencyJ\0011'
  _globals['_PASSWORDLESSCONFIG'].fields_by_name['validity']._loaded_options = None
  _globals['_PASSWORDLESSCONFIG'].fields_by_name['validity']._serialized_options = b'\222A\0372\030Link Validity in SecondsJ\003600'
  _globals['_PASSWORDLESSCONFIG'].fields_by_name['enforce_same_browser_origin']._loaded_options = None
  _globals['_PASSWORDLESSCONFIG'].fields_by_name['enforce_same_browser_origin']._serialized_options = b'\222A#2\033Enforce Same Browser OriginJ\004true'
  _globals['_PASSWORDLESSCONFIG'].fields_by_name['code_challenge_length']._loaded_options = None
  _globals['_PASSWORDLESSCONFIG'].fields_by_name['code_challenge_length']._serialized_options = b'\222A\0322\025Code Challenge LengthJ\0016'
  _globals['_PASSWORDLESSCONFIG'].fields_by_name['code_challenge_type']._loaded_options = None
  _globals['_PASSWORDLESSCONFIG'].fields_by_name['code_challenge_type']._serialized_options = b'\222A 2\023Code Challenge TypeJ\t\"NUMERIC\"'
  _globals['_PASSWORDLESSCONFIG'].fields_by_name['regenerate_passwordless_credentials_on_resend']._loaded_options = None
  _globals['_PASSWORDLESSCONFIG'].fields_by_name['regenerate_passwordless_credentials_on_resend']._serialized_options = b'\222A\0272\017Regenerate the J\004true'
  _globals['_SAMLCONNECTIONCONFIGREQUEST'].fields_by_name['idp_metadata_url']._loaded_options = None
  _globals['_SAMLCONNECTIONCONFIGREQUEST'].fields_by_name['idp_metadata_url']._serialized_options = b'\222A?2\020IDP Metadata URLJ+\"https://youridp.com/service/saml/metadata\"'
  _globals['_SAMLCONNECTIONCONFIGREQUEST'].fields_by_name['idp_entity_id']._loaded_options = None
  _globals['_SAMLCONNECTIONCONFIGREQUEST'].fields_by_name['idp_entity_id']._serialized_options = b'\222A32\rIDP Entity IDJ\"\"https://youridp.com/service/saml\"'
  _globals['_SAMLCONNECTIONCONFIGREQUEST'].fields_by_name['idp_sso_url']._loaded_options = None
  _globals['_SAMLCONNECTIONCONFIGREQUEST'].fields_by_name['idp_sso_url']._serialized_options = b'\222A52\013IDP SSO URLJ&\"https://youridp.com/service/saml/sso\"'
  _globals['_SAMLCONNECTIONCONFIGREQUEST'].fields_by_name['idp_certificate']._loaded_options = None
  _globals['_SAMLCONNECTIONCONFIGREQUEST'].fields_by_name['idp_certificate']._serialized_options = b'\222A\0212\017IDP Certificate'
  _globals['_SAMLCONNECTIONCONFIGREQUEST'].fields_by_name['idp_slo_url']._loaded_options = None
  _globals['_SAMLCONNECTIONCONFIGREQUEST'].fields_by_name['idp_slo_url']._serialized_options = b'\222A52\013IDP SLO URLJ&\"https://youridp.com/service/saml/slo\"'
  _globals['_SAMLCONNECTIONCONFIGREQUEST'].fields_by_name['ui_button_title']._loaded_options = None
  _globals['_SAMLCONNECTIONCONFIGREQUEST'].fields_by_name['ui_button_title']._serialized_options = b'\222A#2\017UI Button TitleJ\020\"Login with SSO\"'
  _globals['_SAMLCONNECTIONCONFIGREQUEST'].fields_by_name['idp_name_id_format']._loaded_options = None
  _globals['_SAMLCONNECTIONCONFIGREQUEST'].fields_by_name['idp_name_id_format']._serialized_options = b'\222A\0352\022IDP Name ID FormatJ\007\"EMAIL\"'
  _globals['_SAMLCONNECTIONCONFIGREQUEST'].fields_by_name['idp_sso_request_binding']._loaded_options = None
  _globals['_SAMLCONNECTIONCONFIGREQUEST'].fields_by_name['idp_sso_request_binding']._serialized_options = b'\222A&2\027IDP SSO Request BindingJ\013\"HTTP_POST\"'
  _globals['_SAMLCONNECTIONCONFIGREQUEST'].fields_by_name['idp_slo_request_binding']._loaded_options = None
  _globals['_SAMLCONNECTIONCONFIGREQUEST'].fields_by_name['idp_slo_request_binding']._serialized_options = b'\222A*2\027IDP SLO Request BindingJ\017\"HTTP_REDIRECT\"'
  _globals['_SAMLCONNECTIONCONFIGREQUEST'].fields_by_name['saml_signing_option']._loaded_options = None
  _globals['_SAMLCONNECTIONCONFIGREQUEST'].fields_by_name['saml_signing_option']._serialized_options = b'\222A32\023SAML Signing OptionJ\034\"SAML_ONLY_RESPONSE_SIGNING\"'
  _globals['_SAMLCONNECTIONCONFIGREQUEST'].fields_by_name['force_authn']._loaded_options = None
  _globals['_SAMLCONNECTIONCONFIGREQUEST'].fields_by_name['force_authn']._serialized_options = b'\222A\0232\013Force AuthnJ\004true'
  _globals['_SAMLCONNECTIONCONFIGREQUEST'].fields_by_name['default_redirect_uri']._loaded_options = None
  _globals['_SAMLCONNECTIONCONFIGREQUEST'].fields_by_name['default_redirect_uri']._serialized_options = b'\222AC2\024Default Redirect URIJ+\"https://yourapp.com/service/saml/redirect\"'
  _globals['_SAMLCONNECTIONCONFIGREQUEST'].fields_by_name['assertion_encrypted']._loaded_options = None
  _globals['_SAMLCONNECTIONCONFIGREQUEST'].fields_by_name['assertion_encrypted']._serialized_options = b'\222A\0332\023Assertion EncryptedJ\004true'
  _globals['_SAMLCONNECTIONCONFIGREQUEST'].fields_by_name['want_request_signed']._loaded_options = None
  _globals['_SAMLCONNECTIONCONFIGREQUEST'].fields_by_name['want_request_signed']._serialized_options = b'\222A\0332\023Want Request SignedJ\004true'
  _globals['_SAMLCONNECTIONCONFIGREQUEST'].fields_by_name['certificate_id']._loaded_options = None
  _globals['_SAMLCONNECTIONCONFIGREQUEST'].fields_by_name['certificate_id']._serialized_options = b'\222A)2\016Certificate IDJ\027\"cer_35585423166144613\"'
  _globals['_SAMLCONNECTIONCONFIGREQUEST'].fields_by_name['idp_slo_required']._loaded_options = None
  _globals['_SAMLCONNECTIONCONFIGREQUEST'].fields_by_name['idp_slo_required']._serialized_options = b'\222A\0312\021Enable IDP logoutJ\004true'
  _globals['_SAMLCONNECTIONCONFIGRESPONSE'].fields_by_name['sp_entity_id']._loaded_options = None
  _globals['_SAMLCONNECTIONCONFIGRESPONSE'].fields_by_name['sp_entity_id']._serialized_options = b'\222A22\014SP Entity IDJ\"\"https://yourapp.com/service/saml\"'
  _globals['_SAMLCONNECTIONCONFIGRESPONSE'].fields_by_name['sp_assertion_url']._loaded_options = None
  _globals['_SAMLCONNECTIONCONFIGRESPONSE'].fields_by_name['sp_assertion_url']._serialized_options = b'\222A@2\020SP Assertion URLJ,\"https://youridp.com/service/saml/assertion\"'
  _globals['_SAMLCONNECTIONCONFIGRESPONSE'].fields_by_name['sp_metadata_url']._loaded_options = None
  _globals['_SAMLCONNECTIONCONFIGRESPONSE'].fields_by_name['sp_metadata_url']._serialized_options = b'\222A>2\017SP Metadata URLJ+\"https://youridp.com/service/saml/metadata\"'
  _globals['_SAMLCONNECTIONCONFIGRESPONSE'].fields_by_name['idp_metadata_url']._loaded_options = None
  _globals['_SAMLCONNECTIONCONFIGRESPONSE'].fields_by_name['idp_metadata_url']._serialized_options = b'\222A?2\020IDP Metadata URLJ+\"https://youridp.com/service/saml/metadata\"'
  _globals['_SAMLCONNECTIONCONFIGRESPONSE'].fields_by_name['idp_entity_id']._loaded_options = None
  _globals['_SAMLCONNECTIONCONFIGRESPONSE'].fields_by_name['idp_entity_id']._serialized_options = b'\222A32\rIDP Entity IDJ\"\"https://youridp.com/service/saml\"'
  _globals['_SAMLCONNECTIONCONFIGRESPONSE'].fields_by_name['idp_sso_url']._loaded_options = None
  _globals['_SAMLCONNECTIONCONFIGRESPONSE'].fields_by_name['idp_sso_url']._serialized_options = b'\222A52\013IDP SSO URLJ&\"https://youridp.com/service/saml/sso\"'
  _globals['_SAMLCONNECTIONCONFIGRESPONSE'].fields_by_name['idp_certificates']._loaded_options = None
  _globals['_SAMLCONNECTIONCONFIGRESPONSE'].fields_by_name['idp_certificates']._serialized_options = b'\222A\0222\020IDP Certificates'
  _globals['_SAMLCONNECTIONCONFIGRESPONSE'].fields_by_name['idp_slo_url']._loaded_options = None
  _globals['_SAMLCONNECTIONCONFIGRESPONSE'].fields_by_name['idp_slo_url']._serialized_options = b'\222A52\013IDP SLO URLJ&\"https://youridp.com/service/saml/slo\"'
  _globals['_SAMLCONNECTIONCONFIGRESPONSE'].fields_by_name['ui_button_title']._loaded_options = None
  _globals['_SAMLCONNECTIONCONFIGRESPONSE'].fields_by_name['ui_button_title']._serialized_options = b'\222A#2\017UI Button TitleJ\020\"Login with SSO\"'
  _globals['_SAMLCONNECTIONCONFIGRESPONSE'].fields_by_name['idp_name_id_format']._loaded_options = None
  _globals['_SAMLCONNECTIONCONFIGRESPONSE'].fields_by_name['idp_name_id_format']._serialized_options = b'\222A\0352\022IDP Name ID FormatJ\007\"EMAIL\"'
  _globals['_SAMLCONNECTIONCONFIGRESPONSE'].fields_by_name['idp_sso_request_binding']._loaded_options = None
  _globals['_SAMLCONNECTIONCONFIGRESPONSE'].fields_by_name['idp_sso_request_binding']._serialized_options = b'\222A&2\027IDP SSO Request BindingJ\013\"HTTP_POST\"'
  _globals['_SAMLCONNECTIONCONFIGRESPONSE'].fields_by_name['idp_slo_request_binding']._loaded_options = None
  _globals['_SAMLCONNECTIONCONFIGRESPONSE'].fields_by_name['idp_slo_request_binding']._serialized_options = b'\222A&2\027IDP SLO Request BindingJ\013\"HTTP_POST\"'
  _globals['_SAMLCONNECTIONCONFIGRESPONSE'].fields_by_name['saml_signing_option']._loaded_options = None
  _globals['_SAMLCONNECTIONCONFIGRESPONSE'].fields_by_name['saml_signing_option']._serialized_options = b'\222A32\023SAML Signing OptionJ\034\"SAML_ONLY_RESPONSE_SIGNING\"'
  _globals['_SAMLCONNECTIONCONFIGRESPONSE'].fields_by_name['allow_idp_initiated_login']._loaded_options = None
  _globals['_SAMLCONNECTIONCONFIGRESPONSE'].fields_by_name['allow_idp_initiated_login']._serialized_options = b'\222A!2\031Allow IDP Initiated LoginJ\004true'
  _globals['_SAMLCONNECTIONCONFIGRESPONSE'].fields_by_name['force_authn']._loaded_options = None
  _globals['_SAMLCONNECTIONCONFIGRESPONSE'].fields_by_name['force_authn']._serialized_options = b'\222A\0232\013Force AuthnJ\004true'
  _globals['_SAMLCONNECTIONCONFIGRESPONSE'].fields_by_name['default_redirect_uri']._loaded_options = None
  _globals['_SAMLCONNECTIONCONFIGRESPONSE'].fields_by_name['default_redirect_uri']._serialized_options = b'\222AC2\024Default Redirect URIJ+\"https://yourapp.com/service/saml/redirect\"'
  _globals['_SAMLCONNECTIONCONFIGRESPONSE'].fields_by_name['assertion_encrypted']._loaded_options = None
  _globals['_SAMLCONNECTIONCONFIGRESPONSE'].fields_by_name['assertion_encrypted']._serialized_options = b'\222A\0332\023Assertion EncryptedJ\004true'
  _globals['_SAMLCONNECTIONCONFIGRESPONSE'].fields_by_name['want_request_signed']._loaded_options = None
  _globals['_SAMLCONNECTIONCONFIGRESPONSE'].fields_by_name['want_request_signed']._serialized_options = b'\222A\0332\023Want Request SignedJ\004true'
  _globals['_SAMLCONNECTIONCONFIGRESPONSE'].fields_by_name['certificate_id']._loaded_options = None
  _globals['_SAMLCONNECTIONCONFIGRESPONSE'].fields_by_name['certificate_id']._serialized_options = b'\222A)2\016Certificate IDJ\027\"cer_35585423166144613\"'
  _globals['_SAMLCONNECTIONCONFIGRESPONSE'].fields_by_name['idp_slo_required']._loaded_options = None
  _globals['_SAMLCONNECTIONCONFIGRESPONSE'].fields_by_name['idp_slo_required']._serialized_options = b'\222A\0312\021Enable IDP logoutJ\004true'
  _globals['_SAMLCONNECTIONCONFIGRESPONSE'].fields_by_name['sp_slo_url']._loaded_options = None
  _globals['_SAMLCONNECTIONCONFIGRESPONSE'].fields_by_name['sp_slo_url']._serialized_options = b'\222AT2\030Service Provider SLO urlJ8\"https://yourapp.com/sso/v1/saml/conn_1234/slo/callback\"\340A\003'
  _globals['_IDPCERTIFICATE'].fields_by_name['certificate']._loaded_options = None
  _globals['_IDPCERTIFICATE'].fields_by_name['certificate']._serialized_options = b'\222A\0212\017IDP Certificate'
  _globals['_IDPCERTIFICATE'].fields_by_name['create_time']._loaded_options = None
  _globals['_IDPCERTIFICATE'].fields_by_name['create_time']._serialized_options = b'\222A32\031Certificate Creation TimeJ\026\"2021-09-01T00:00:00Z\"'
  _globals['_IDPCERTIFICATE'].fields_by_name['expiry_time']._loaded_options = None
  _globals['_IDPCERTIFICATE'].fields_by_name['expiry_time']._serialized_options = b'\222A12\027Certificate Expiry TimeJ\026\"2021-09-01T00:00:00Z\"'
  _globals['_IDPCERTIFICATE'].fields_by_name['id']._loaded_options = None
  _globals['_IDPCERTIFICATE'].fields_by_name['id']._serialized_options = b'\222A%2\016Certificate IDJ\023\"cert_123123123123\"'
  _globals['_IDPCERTIFICATE'].fields_by_name['issuer']._loaded_options = None
  _globals['_IDPCERTIFICATE'].fields_by_name['issuer']._serialized_options = b'\222A82\022Certificate IssuerJ\"\"https://youridp.com/service/saml\"'
  _globals['_OIDCMETADATAREQUEST'].fields_by_name['issuer']._loaded_options = None
  _globals['_OIDCMETADATAREQUEST'].fields_by_name['issuer']._serialized_options = b'\272H\007r\005\020\001\030\310\001'
  _globals['_SAMLMETADATAREQUEST'].fields_by_name['metadata_url']._loaded_options = None
  _globals['_SAMLMETADATAREQUEST'].fields_by_name['metadata_url']._serialized_options = b'\272H\007r\005\020\001\030\310\001'
  _globals['_SAMLCERTIFICATEREQUEST'].fields_by_name['text']._loaded_options = None
  _globals['_SAMLCERTIFICATEREQUEST'].fields_by_name['text']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_GETCONNECTIONTESTRESULTREQUEST'].fields_by_name['connection_id']._loaded_options = None
  _globals['_GETCONNECTIONTESTRESULTREQUEST'].fields_by_name['connection_id']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_GETCONNECTIONTESTRESULTREQUEST'].fields_by_name['test_request_id']._loaded_options = None
  _globals['_GETCONNECTIONTESTRESULTREQUEST'].fields_by_name['test_request_id']._serialized_options = b'\272H\013r\t\020\001:\005test_'
  _globals['_LISTAPPCONNECTIONSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTAPPCONNECTIONSREQUEST'].fields_by_name['page_size']._serialized_options = b'\222AY2SMaximum number of organizations to return per page. Value must be between 1 and 30.J\00230\272H\004*\002\030\036'
  _globals['_LISTAPPCONNECTIONSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTAPPCONNECTIONSREQUEST'].fields_by_name['page_token']._serialized_options = b'\222A\201\0012aToken from a previous response for pagination. Provide this to retrieve the next page of results.J\034eyJwYWdlIjoyLCJsaW1pdCI6MzB9'
  _globals['_LISTAPPCONNECTIONSREQUEST'].fields_by_name['provider']._loaded_options = None
  _globals['_LISTAPPCONNECTIONSREQUEST'].fields_by_name['provider']._serialized_options = b'\222A(2\036Filter connections by providerJ\006\"OKTA\"\272H\006r\004\020\001\0302'
  _globals['_LISTAPPCONNECTIONSRESPONSE'].fields_by_name['connections']._loaded_options = None
  _globals['_LISTAPPCONNECTIONSRESPONSE'].fields_by_name['connections']._serialized_options = b'\222A321List of connections matching the request criteria'
  _globals['_LISTAPPCONNECTIONSRESPONSE'].fields_by_name['next_page_token']._loaded_options = None
  _globals['_LISTAPPCONNECTIONSRESPONSE'].fields_by_name['next_page_token']._serialized_options = b'\222AD2\"Token for the next page of resultsJ\036\"eyJwYWdlIjoyLCJsaW1pdCI6MzB9\"'
  _globals['_LISTAPPCONNECTIONSRESPONSE'].fields_by_name['prev_page_token']._loaded_options = None
  _globals['_LISTAPPCONNECTIONSRESPONSE'].fields_by_name['prev_page_token']._serialized_options = b'\222AH2&Token for the previous page of resultsJ\036\"eyJwYWdlIjoyLCJsaW1pdCI6MzB9\"'
  _globals['_LISTAPPCONNECTIONSRESPONSE'].fields_by_name['total_size']._loaded_options = None
  _globals['_LISTAPPCONNECTIONSRESPONSE'].fields_by_name['total_size']._serialized_options = b'\222A@29Total number of connections matching the request criteriaJ\003100'
  _globals['_CONNECTIONSERVICE']._loaded_options = None
  _globals['_CONNECTIONSERVICE']._serialized_options = b'\222A\226\001\n\013Connections\022\206\001Manage enterprise connections for your Scalekit environment. This service provides endpoints for retrieving, and updating connections.'
  _globals['_CONNECTIONSERVICE'].methods_by_name['CreateEnvironmentConnection']._loaded_options = None
  _globals['_CONNECTIONSERVICE'].methods_by_name['CreateEnvironmentConnection']._serialized_options = b'\222A\301\001\n\013Connections\022\027Create a new connection\0328Establish a new connection for the specified environmentJ_\n\003201\022X\n\037Connection created successfully\0225\n3\0321.scalekit.v1.connections.CreateConnectionResponse\202\265\030\002\030T\372\322\344\223\002\t\022\007PREVIEW\202\323\344\223\002!\"\023/api/v1/connections:\nconnection'
  _globals['_CONNECTIONSERVICE'].methods_by_name['CreateConnection']._loaded_options = None
  _globals['_CONNECTIONSERVICE'].methods_by_name['CreateConnection']._serialized_options = b'\222A\274\006\n\013Connections\022\027Create a new connection\032=Establish a new SSO connection for the specified organizationJ_\n\003201\022X\n\037Connection created successfully\0225\n3\0321.scalekit.v1.connections.CreateConnectionResponsej\363\004\n\rx-codeSamples\022\341\0042\336\004\n\231\001*\226\001\n\026\n\005label\022\r\032\013Node.js SDK\n\024\n\004lang\022\014\032\njavascript\nf\n\006source\022\\\032Zconst connection = await sc.connection.createConnection(organizationId, connectionConfig);\n\220\001*\215\001\n\025\n\005label\022\014\032\nPython SDK\n\020\n\004lang\022\010\032\006python\nb\n\006source\022X\032Vconnection = sc.connection.create_connection(\n  organization_id,\n  connection_config\n)\n\223\001*\220\001\n\021\n\005label\022\010\032\006Go SDK\n\014\n\004lang\022\004\032\002go\nm\n\006source\022c\032aconnection, err := sc.Connection.CreateConnection(\n  ctx,\n  organizationId,\n  connectionConfig,\n)\n\226\001*\223\001\n\023\n\005label\022\n\032\010Java SDK\n\016\n\004lang\022\006\032\004java\nl\n\006source\022b\032`Connection connection = client.connections().createConnection(organizationId, connectionConfig);\202\265\030\002\030t\372\322\344\223\002\t\022\007PREVIEW\202\323\344\223\002A\"3/api/v1/organizations/{organization_id}/connections:\nconnection'
  _globals['_CONNECTIONSERVICE'].methods_by_name['AssignDomainsToConnection']._loaded_options = None
  _globals['_CONNECTIONSERVICE'].methods_by_name['AssignDomainsToConnection']._serialized_options = b'\222A\266\002\n\013Connections\022\036Assign domains to a connection\032\236\001Assigns one or more domains to a specific connection within an organization. This allows the connection to be used for authentication on the specified domainsJf\n\003200\022_\n\035Domains assigned successfully\022>\n<\032:.scalekit.v1.connections.AssignDomainsToConnectionResponse\202\265\030\002\030t\372\322\344\223\002\t\022\007PREVIEW\202\323\344\223\002P\032K/api/v1/organizations/{organization_id}/connections/{connection_id}/domains:\001*'
  _globals['_CONNECTIONSERVICE'].methods_by_name['GetEnvironmentConnection']._loaded_options = None
  _globals['_CONNECTIONSERVICE'].methods_by_name['GetEnvironmentConnection']._serialized_options = b'\222A\347\001\n\013Connections\022\033Retrieve connection details\032SObtain detailed information about a specific connection using its unique identifierJf\n\003200\022_\n)Successfully retrieved connection details\0222\n0\032..scalekit.v1.connections.GetConnectionResponse\202\265\030\002\030T\372\322\344\223\002\t\022\007PREVIEW\202\323\344\223\002%\022#/api/v1/connections/{connection_id}'
  _globals['_CONNECTIONSERVICE'].methods_by_name['GetConnection']._loaded_options = None
  _globals['_CONNECTIONSERVICE'].methods_by_name['GetConnection']._serialized_options = b'\222A\346\007\n\013Connections\022\026Get connection details\032\321\001Retrieves the complete configuration and status details for a specific connection by its ID within an organization. Returns all connection properties including provider settings, protocols, and current status.J\205\001\n\003200\022~\nHSuccessfully retrieved connection details for the specified organization\0222\n0\032..scalekit.v1.connections.GetConnectionResponsej\342\004\n\rx-codeSamples\022\320\0042\315\004\n\230\001*\225\001\n\026\n\005label\022\r\032\013Node.js SDK\n\024\n\004lang\022\014\032\njavascript\ne\n\006source\022[\032Yconst connection = await sc.connection.getConnection(\n  organizationId,\n  connectionId\n);\n\212\001*\207\001\n\025\n\005label\022\014\032\nPython SDK\n\020\n\004lang\022\010\032\006python\n\\\n\006source\022R\032Pconnection = sc.connection.get_connection(\n  organization_id,\n  connection_id,\n)\n\214\001*\211\001\n\021\n\005label\022\010\032\006Go SDK\n\014\n\004lang\022\004\032\002go\nf\n\006source\022\\\032Zconnection, err := sc.Connection.GetConnection(\n  ctx,\n  organizationId,\n  connectionId,\n)\n\223\001*\220\001\n\023\n\005label\022\n\032\010Java SDK\n\016\n\004lang\022\006\032\004java\ni\n\006source\022_\032]Connection connection = client.connections().getConnectionById(connectionId, organizationId);\202\265\030\002\030t\202\323\344\223\002:\0228/api/v1/organizations/{organization_id}/connections/{id}'
  _globals['_CONNECTIONSERVICE'].methods_by_name['ListConnections']._loaded_options = None
  _globals['_CONNECTIONSERVICE'].methods_by_name['ListConnections']._serialized_options = b'\222A\243\013\n\013Connections\022\020List connections\0322Retrieves a list of connections in the environmentJa\n\003200\022Z\n\"Successfully retrieved connections\0224\n2\0320.scalekit.v1.connections.ListConnectionsResponsej\352\t\n\rx-codeSamples\022\330\t2\325\t\n\245\002*\242\002\n\026\n\005label\022\r\032\013Node.js SDK\n\024\n\004lang\022\014\032\njavascript\n\361\001\n\006source\022\346\001\032\343\001// List connections by organization id\nconst connections = await scalekit.connection.listConnections(organizationId);\n\n// List connections by domain\nconst connections = await scalekit.connection.listConnectionsByDomain(domain);\n\246\002*\243\002\n\025\n\005label\022\014\032\nPython SDK\n\020\n\004lang\022\010\032\006python\n\367\001\n\006source\022\354\001\032\351\001# List connections by organization id\nconnections = scalekit_client.connection.list_connections(\n  organization_id\n)\n\n# List connections by domain\nresponse = scalekit_client.connection.list_connections_by_domain(domain=\"example.com\")\n\255\002*\252\002\n\021\n\005label\022\010\032\006Go SDK\n\014\n\004lang\022\004\032\002go\n\206\002\n\006source\022\373\001\032\370\001// List connections by organization id\nconnections, err := scalekitClient.Connection().ListConnections(\n  ctx,\n  organizationId\n)\n\n// List connections by domain\nconnections, err := scalekitClient.Connection().ListConnectionsByDomain(ctx, \n  domain)\n\321\002*\316\002\n\023\n\005label\022\n\032\010Java SDK\n\016\n\004lang\022\006\032\004java\n\246\002\n\006source\022\233\002\032\230\002// List connections by organization id\nListConnectionsResponse response = scalekitClient.connections(\n  ).listConnections(organizationId);\n\n// List connections by domain\nListConnectionsResponse response = scalekitClient.connections(\n  ).listConnectionsByDomain(\"your-domain.com\");\202\265\030\002\030t\202\323\344\223\002\025\022\023/api/v1/connections'
  _globals['_CONNECTIONSERVICE'].methods_by_name['ListOrganizationConnections']._loaded_options = None
  _globals['_CONNECTIONSERVICE'].methods_by_name['ListOrganizationConnections']._serialized_options = b'\222A\326\001\n\013Connections\022\035List organization connections\0329Retrieves a list of connections for all the organizationsJm\n\003200\022f\n\"Successfully retrieved connections\022@\n>\032<.scalekit.v1.connections.ListOrganizationConnectionsResponse\202\265\030\002\030T\372\322\344\223\002\t\022\007PREVIEW\202\323\344\223\002%\022#/api/v1/organizations/-/connections'
  _globals['_CONNECTIONSERVICE'].methods_by_name['SearchOrganizationConnections']._loaded_options = None
  _globals['_CONNECTIONSERVICE'].methods_by_name['SearchOrganizationConnections']._serialized_options = b'\222A\341\001\n\013Connections\022\037Search organization connections\032DSearch with query or filters provided and return list of connectionsJk\n\003200\022d\n\036Successfully found connections\022B\n@\032>.scalekit.v1.connections.SearchOrganizationConnectionsResponse\202\265\030\002\030T\372\322\344\223\002\t\022\007PREVIEW\202\323\344\223\002,\022*/api/v1/organizations/-/connections:search'
  _globals['_CONNECTIONSERVICE'].methods_by_name['UpdateEnvironmentConnection']._loaded_options = None
  _globals['_CONNECTIONSERVICE'].methods_by_name['UpdateEnvironmentConnection']._serialized_options = b'\222A\221\001\n\013Connections\022\023Update a connection\032\027Update a SSO ConnectionJT\n\003200\022M\n\024Updated Successfully\0225\n3\0321.scalekit.v1.connections.UpdateConnectionResponse\202\265\030\002\030T\372\322\344\223\002\t\022\007PREVIEW\202\323\344\223\00212#/api/v1/connections/{connection_id}:\nconnection'
  _globals['_CONNECTIONSERVICE'].methods_by_name['UpdateConnection']._loaded_options = None
  _globals['_CONNECTIONSERVICE'].methods_by_name['UpdateConnection']._serialized_options = b'\222A\325\006\n\013Connections\022$Update a connection for organization\032\027Update a SSO ConnectionJT\n\003200\022M\n\024Updated Successfully\0225\n3\0321.scalekit.v1.connections.UpdateConnectionResponsej\260\005\n\rx-codeSamples\022\236\0052\233\005\n\247\001*\244\001\n\026\n\005label\022\r\032\013Node.js SDK\n\024\n\004lang\022\014\032\njavascript\nt\n\006source\022j\032hconst connection = await sc.connection.updateConnection(organizationId, connectionId, connectionConfig);\n\241\001*\236\001\n\025\n\005label\022\014\032\nPython SDK\n\020\n\004lang\022\010\032\006python\ns\n\006source\022i\032gconnection = sc.connection.update_connection(\n  organization_id,\n  connection_id,\n  connection_config\n)\n\243\001*\240\001\n\021\n\005label\022\010\032\006Go SDK\n\014\n\004lang\022\004\032\002go\n}\n\006source\022s\032qconnection, err := sc.Connection.UpdateConnection(\n  ctx,\n  organizationId,\n  connectionId,\n  connectionConfig,\n)\n\244\001*\241\001\n\023\n\005label\022\n\032\010Java SDK\n\016\n\004lang\022\006\032\004java\nz\n\006source\022p\032nConnection connection = client.connections().updateConnection(connectionId, organizationId, connectionConfig);\202\265\030\002\030t\372\322\344\223\002\t\022\007PREVIEW\202\323\344\223\002F28/api/v1/organizations/{organization_id}/connections/{id}:\nconnection'
  _globals['_CONNECTIONSERVICE'].methods_by_name['DeleteEnvironmentConnection']._loaded_options = None
  _globals['_CONNECTIONSERVICE'].methods_by_name['DeleteEnvironmentConnection']._serialized_options = b'\222AZ\n\013Connections\022\023Delete a connection\032\027Delete a SSO ConnectionJ\035\n\003200\022\026\n\024Deleted Successfully\202\265\030\002\030T\372\322\344\223\002\t\022\007PREVIEW\202\323\344\223\002%*#/api/v1/connections/{connection_id}'
  _globals['_CONNECTIONSERVICE'].methods_by_name['DeleteConnection']._loaded_options = None
  _globals['_CONNECTIONSERVICE'].methods_by_name['DeleteConnection']._serialized_options = b'\222A\210\005\n\013Connections\022$Delete a connection for organization\032\027Delete a SSO ConnectionJ\035\n\003200\022\026\n\024Deleted Successfullyj\232\004\n\rx-codeSamples\022\210\0042\205\004\n\201\001*\177\n\026\n\005label\022\r\032\013Node.js SDK\n\024\n\004lang\022\014\032\njavascript\nO\n\006source\022E\032Cawait sc.connection.deleteConnection(organizationId, connectionId);\n~*|\n\025\n\005label\022\014\032\nPython SDK\n\020\n\004lang\022\010\032\006python\nQ\n\006source\022G\032Esc.connection.delete_connection(\n  organization_id,\n  connection_id\n)\n\203\001*\200\001\n\021\n\005label\022\010\032\006Go SDK\n\014\n\004lang\022\004\032\002go\n]\n\006source\022S\032Qerr := sc.Connection.DeleteConnection(\n  ctx,\n  organizationId,\n  connectionId,\n)\ny*w\n\023\n\005label\022\n\032\010Java SDK\n\016\n\004lang\022\006\032\004java\nP\n\006source\022F\032Dclient.connections().deleteConnection(connectionId, organizationId);\202\265\030\002\030t\372\322\344\223\002\t\022\007PREVIEW\202\323\344\223\002:*8/api/v1/organizations/{organization_id}/connections/{id}'
  _globals['_CONNECTIONSERVICE'].methods_by_name['EnableEnvironmentConnection']._loaded_options = None
  _globals['_CONNECTIONSERVICE'].methods_by_name['EnableEnvironmentConnection']._serialized_options = b'\222A\204\001\n\013Connections\022\023Enable a connection\032\027Enable a SSO ConnectionJG\n\003200\022@\n\007Success\0225\n3\0321.scalekit.v1.connections.ToggleConnectionResponse\202\265\030\002\030T\372\322\344\223\002\t\022\007PREVIEW\202\323\344\223\002,2*/api/v1/connections/{connection_id}:enable'
  _globals['_CONNECTIONSERVICE'].methods_by_name['EnableConnection']._loaded_options = None
  _globals['_CONNECTIONSERVICE'].methods_by_name['EnableConnection']._serialized_options = b'\222A\313\007\n\013Connections\022\036Enable organization connection\032\356\001Activate an existing connection for the specified organization. When enabled, users can authenticate using this connection. This endpoint changes the connection state from disabled to enabled without modifying other configuration settingsJ_\n\003200\022X\n\037Connection enabled successfully\0225\n3\0321.scalekit.v1.connections.ToggleConnectionResponsej\311\004\n\rx-codeSamples\022\267\0042\264\004\n\201\001*\177\n\026\n\005label\022\r\032\013Node.js SDK\n\024\n\004lang\022\014\032\njavascript\nO\n\006source\022E\032Cawait sc.connection.enableConnection(organizationId, connectionId);\n\177*}\n\025\n\005label\022\014\032\nPython SDK\n\020\n\004lang\022\010\032\006python\nR\n\006source\022H\032Fsc.connection.enable_connection(\n  organization_id,\n  connection_id,\n)\n\203\001*\200\001\n\021\n\005label\022\010\032\006Go SDK\n\014\n\004lang\022\004\032\002go\n]\n\006source\022S\032Qerr := sc.Connection.EnableConnection(\n  ctx,\n  organizationId,\n  connectionId,\n)\n\246\001*\243\001\n\023\n\005label\022\n\032\010Java SDK\n\016\n\004lang\022\006\032\004java\n|\n\006source\022r\032pToggleConnectionResponse response = scalekitClient.connections().enableConnection(connectionId, organizationId);\202\265\030\002\030t\202\323\344\223\002A2?/api/v1/organizations/{organization_id}/connections/{id}:enable'
  _globals['_CONNECTIONSERVICE'].methods_by_name['DisableEnvironmentConnection']._loaded_options = None
  _globals['_CONNECTIONSERVICE'].methods_by_name['DisableEnvironmentConnection']._serialized_options = b'\222A\206\001\n\013Connections\022\024Disable a connection\032\030Disable a SSO ConnectionJG\n\003200\022@\n\007Success\0225\n3\0321.scalekit.v1.connections.ToggleConnectionResponse\202\265\030\002\030T\372\322\344\223\002\t\022\007PREVIEW\202\323\344\223\002-2+/api/v1/connections/{connection_id}:disable'
  _globals['_CONNECTIONSERVICE'].methods_by_name['DisableConnection']._loaded_options = None
  _globals['_CONNECTIONSERVICE'].methods_by_name['DisableConnection']._serialized_options = b'\222A\327\007\n\013Connections\022\037Disable organization connection\032\364\001Deactivate an existing connection for the specified organization. When disabled, users cannot authenticate using this connection. This endpoint changes the connection state from enabled to disabled without modifying other configuration settingsJ`\n\003200\022Y\n Connection disabled successfully\0225\n3\0321.scalekit.v1.connections.ToggleConnectionResponsej\315\004\n\rx-codeSamples\022\273\0042\270\004\n\203\001*\200\001\n\026\n\005label\022\r\032\013Node.js SDK\n\024\n\004lang\022\014\032\njavascript\nP\n\006source\022F\032Dawait sc.connection.disableConnection(organizationId, connectionId);\n\177*}\n\025\n\005label\022\014\032\nPython SDK\n\020\n\004lang\022\010\032\006python\nR\n\006source\022H\032Fsc.connection.disable_connection(\n  organization_id,\n  connection_id\n)\n\204\001*\201\001\n\021\n\005label\022\010\032\006Go SDK\n\014\n\004lang\022\004\032\002go\n^\n\006source\022T\032Rerr := sc.Connection.DisableConnection(\n  ctx,\n  organizationId,\n  connectionId,\n)\n\247\001*\244\001\n\023\n\005label\022\n\032\010Java SDK\n\016\n\004lang\022\006\032\004java\n}\n\006source\022s\032qToggleConnectionResponse response = scalekitClient.connections().disableConnection(connectionId, organizationId);\202\265\030\002\030t\202\323\344\223\002B2@/api/v1/organizations/{organization_id}/connections/{id}:disable'
  _globals['_CONNECTIONSERVICE'].methods_by_name['GetConnectionTestResult']._loaded_options = None
  _globals['_CONNECTIONSERVICE'].methods_by_name['GetConnectionTestResult']._serialized_options = b'\222A\215\001\n\013Connections\022\026Test connection result\032\026Connection test resultJN\n\003200\022G\n\007Success\022<\n:\0328.scalekit.v1.connections.GetConnectionTestResultResponse\202\265\030\002\030t\372\322\344\223\002\t\022\007PREVIEW\202\323\344\223\002E\022C/api/v1/connections/{connection_id}/test-requests/{test_request_id}'
  _globals['_CONNECTIONSERVICE'].methods_by_name['ListAppConnections']._loaded_options = None
  _globals['_CONNECTIONSERVICE'].methods_by_name['ListAppConnections']._serialized_options = b'\222A\202\006\n\013Connections\022\024List App connections\0326Retrieves a list of app connections in the environmentJa\n\003200\022Z\n\"Successfully retrieved connections\0224\n2\0320.scalekit.v1.connections.ListConnectionsResponsej\301\004\n\rx-codeSamples\022\257\0042\254\004\n\207\001*\204\001\n\026\n\005label\022\r\032\013Node.js SDK\n\024\n\004lang\022\014\032\njavascript\nT\n\006source\022J\032Hconst connections = await sc.connection.listConnections(organizationId);\nz*x\n\025\n\005label\022\014\032\nPython SDK\n\020\n\004lang\022\010\032\006python\nM\n\006source\022C\032Aconnections = sc.connection.list_connections(\n  organization_id\n)\n}*{\n\021\n\005label\022\010\032\006Go SDK\n\014\n\004lang\022\004\032\002go\nX\n\006source\022N\032Lconnections, err := sc.Connection.ListConnections(\n  ctx,\n  organizationId\n)\n\244\001*\241\001\n\023\n\005label\022\n\032\010Java SDK\n\016\n\004lang\022\006\032\004java\nz\n\006source\022p\032nListConnectionsResponse response = scalekitClient.connections().listConnectionsByOrganization(organizationId);\202\265\030\002\030t\372\322\344\223\002\t\022\007PREVIEW\202\323\344\223\002\031\022\027/api/v1/connections/app'
  _globals['_CODECHALLENGETYPE']._serialized_start=27247
  _globals['_CODECHALLENGETYPE']._serialized_end=27334
  _globals['_CONFIGURATIONTYPE']._serialized_start=27336
  _globals['_CONFIGURATIONTYPE']._serialized_end=27418
  _globals['_NAMEIDFORMAT']._serialized_start=27420
  _globals['_NAMEIDFORMAT']._serialized_end=27517
  _globals['_PASSWORDLESSTYPE']._serialized_start=27519
  _globals['_PASSWORDLESSTYPE']._serialized_end=27604
  _globals['_TESTRESULTSTATUS']._serialized_start=27606
  _globals['_TESTRESULTSTATUS']._serialized_end=27663
  _globals['_SAMLSIGNINGOPTIONS']._serialized_start=27666
  _globals['_SAMLSIGNINGOPTIONS']._serialized_end=27882
  _globals['_REQUESTBINDING']._serialized_start=27884
  _globals['_REQUESTBINDING']._serialized_end=27967
  _globals['_TOKENAUTHTYPE']._serialized_start=27969
  _globals['_TOKENAUTHTYPE']._serialized_end=28049
  _globals['_OIDCSCOPE']._serialized_start=28051
  _globals['_OIDCSCOPE']._serialized_end=28150
  _globals['_CONNECTIONTYPE']._serialized_start=28153
  _globals['_CONNECTIONTYPE']._serialized_end=28281
  _globals['_CONNECTIONSTATUS']._serialized_start=28283
  _globals['_CONNECTIONSTATUS']._serialized_end=28379
  _globals['_CONNECTIONPROVIDER']._serialized_start=28382
  _globals['_CONNECTIONPROVIDER']._serialized_end=28662
  _globals['_ASSIGNDOMAINSTOCONNECTIONREQUEST']._serialized_start=501
  _globals['_ASSIGNDOMAINSTOCONNECTIONREQUEST']._serialized_end=697
  _globals['_ASSIGNDOMAINSTOCONNECTIONRESPONSE']._serialized_start=700
  _globals['_ASSIGNDOMAINSTOCONNECTIONRESPONSE']._serialized_end=1186
  _globals['_GETPROVIDERSREQUEST']._serialized_start=1188
  _globals['_GETPROVIDERSREQUEST']._serialized_end=1209
  _globals['_GETPROVIDERSRESPONSE']._serialized_start=1211
  _globals['_GETPROVIDERSRESPONSE']._serialized_end=1298
  _globals['_PROVIDER']._serialized_start=1301
  _globals['_PROVIDER']._serialized_end=1544
  _globals['_CREATEENVIRONMENTCONNECTIONREQUEST']._serialized_start=1547
  _globals['_CREATEENVIRONMENTCONNECTIONREQUEST']._serialized_end=1849
  _globals['_CREATECONNECTIONREQUEST']._serialized_start=1852
  _globals['_CREATECONNECTIONREQUEST']._serialized_end=2123
  _globals['_CREATECONNECTION']._serialized_start=2126
  _globals['_CREATECONNECTION']._serialized_end=2615
  _globals['_CONNECTION']._serialized_start=2618
  _globals['_CONNECTION']._serialized_end=6609
  _globals['_CONNECTION_ATTRIBUTEMAPPINGENTRY']._serialized_start=6493
  _globals['_CONNECTION_ATTRIBUTEMAPPINGENTRY']._serialized_end=6560
  _globals['_CREATECONNECTIONRESPONSE']._serialized_start=6611
  _globals['_CREATECONNECTIONRESPONSE']._serialized_end=6730
  _globals['_UPDATEENVIRONMENTCONNECTIONREQUEST']._serialized_start=6733
  _globals['_UPDATEENVIRONMENTCONNECTIONREQUEST']._serialized_end=7029
  _globals['_UPDATECONNECTIONREQUEST']._serialized_start=7032
  _globals['_UPDATECONNECTIONREQUEST']._serialized_end=7409
  _globals['_UPDATECONNECTION']._serialized_start=7412
  _globals['_UPDATECONNECTION']._serialized_end=9212
  _globals['_UPDATECONNECTION_ATTRIBUTEMAPPINGENTRY']._serialized_start=6493
  _globals['_UPDATECONNECTION_ATTRIBUTEMAPPINGENTRY']._serialized_end=6560
  _globals['_UPDATECONNECTIONRESPONSE']._serialized_start=9215
  _globals['_UPDATECONNECTIONRESPONSE']._serialized_end=9343
  _globals['_DELETEENVIRONMENTCONNECTIONREQUEST']._serialized_start=9346
  _globals['_DELETEENVIRONMENTCONNECTIONREQUEST']._serialized_end=9502
  _globals['_DELETECONNECTIONREQUEST']._serialized_start=9505
  _globals['_DELETECONNECTIONREQUEST']._serialized_end=9750
  _globals['_GETENVIRONMENTCONNECTIONREQUEST']._serialized_start=9753
  _globals['_GETENVIRONMENTCONNECTIONREQUEST']._serialized_end=9899
  _globals['_GETCONNECTIONREQUEST']._serialized_start=9902
  _globals['_GETCONNECTIONREQUEST']._serialized_end=10282
  _globals['_GETCONNECTIONRESPONSE']._serialized_start=10285
  _globals['_GETCONNECTIONRESPONSE']._serialized_end=10567
  _globals['_LISTCONNECTIONSREQUEST']._serialized_start=10570
  _globals['_LISTCONNECTIONSREQUEST']._serialized_end=11104
  _globals['_LISTCONNECTIONSRESPONSE']._serialized_start=11107
  _globals['_LISTCONNECTIONSRESPONSE']._serialized_end=11264
  _globals['_LISTCONNECTION']._serialized_start=11267
  _globals['_LISTCONNECTION']._serialized_end=12797
  _globals['_LISTORGANIZATIONCONNECTIONSREQUEST']._serialized_start=12800
  _globals['_LISTORGANIZATIONCONNECTIONSREQUEST']._serialized_end=13135
  _globals['_LISTORGANIZATIONCONNECTIONSRESPONSE']._serialized_start=13138
  _globals['_LISTORGANIZATIONCONNECTIONSRESPONSE']._serialized_end=13417
  _globals['_SEARCHORGANIZATIONCONNECTIONSREQUEST']._serialized_start=13420
  _globals['_SEARCHORGANIZATIONCONNECTIONSREQUEST']._serialized_end=14350
  _globals['_SEARCHORGANIZATIONCONNECTIONSRESPONSE']._serialized_start=14353
  _globals['_SEARCHORGANIZATIONCONNECTIONSRESPONSE']._serialized_end=14634
  _globals['_TOGGLEENVIRONMENTCONNECTIONREQUEST']._serialized_start=14637
  _globals['_TOGGLEENVIRONMENTCONNECTIONREQUEST']._serialized_end=14793
  _globals['_TOGGLECONNECTIONREQUEST']._serialized_start=14796
  _globals['_TOGGLECONNECTIONREQUEST']._serialized_end=15082
  _globals['_TOGGLECONNECTIONRESPONSE']._serialized_start=15085
  _globals['_TOGGLECONNECTIONRESPONSE']._serialized_end=15401
  _globals['_OIDCCONNECTIONCONFIG']._serialized_start=15404
  _globals['_OIDCCONNECTIONCONFIG']._serialized_end=17350
  _globals['_OAUTHCONNECTIONCONFIG']._serialized_start=17353
  _globals['_OAUTHCONNECTIONCONFIG']._serialized_end=18510
  _globals['_PASSWORDLESSCONFIG']._serialized_start=18513
  _globals['_PASSWORDLESSCONFIG']._serialized_end=19525
  _globals['_STATICAUTHCONFIG']._serialized_start=19527
  _globals['_STATICAUTHCONFIG']._serialized_end=19607
  _globals['_SAMLCONNECTIONCONFIGREQUEST']._serialized_start=19610
  _globals['_SAMLCONNECTIONCONFIGREQUEST']._serialized_end=21573
  _globals['_SAMLCONNECTIONCONFIGRESPONSE']._serialized_start=21576
  _globals['_SAMLCONNECTIONCONFIGRESPONSE']._serialized_end=24129
  _globals['_IDPCERTIFICATE']._serialized_start=24132
  _globals['_IDPCERTIFICATE']._serialized_end=24579
  _globals['_GETOIDCMETADATAREQUEST']._serialized_start=24581
  _globals['_GETOIDCMETADATAREQUEST']._serialized_end=24679
  _globals['_OIDCMETADATAREQUEST']._serialized_start=24681
  _globals['_OIDCMETADATAREQUEST']._serialized_end=24738
  _globals['_GETOIDCMETADATARESPONSE']._serialized_start=24741
  _globals['_GETOIDCMETADATARESPONSE']._serialized_end=24956
  _globals['_GETSAMLMETADATAREQUEST']._serialized_start=24958
  _globals['_GETSAMLMETADATAREQUEST']._serialized_end=25056
  _globals['_SAMLMETADATAREQUEST']._serialized_start=25058
  _globals['_SAMLMETADATAREQUEST']._serialized_end=25126
  _globals['_GETSAMLMETADATARESPONSE']._serialized_start=25129
  _globals['_GETSAMLMETADATARESPONSE']._serialized_end=25437
  _globals['_GETSAMLCERTIFICATEDETAILSREQUEST']._serialized_start=25439
  _globals['_GETSAMLCERTIFICATEDETAILSREQUEST']._serialized_end=25556
  _globals['_SAMLCERTIFICATEREQUEST']._serialized_start=25558
  _globals['_SAMLCERTIFICATEREQUEST']._serialized_end=25611
  _globals['_GETSAMLCERTIFICATEDETAILSRESPONSE']._serialized_start=25614
  _globals['_GETSAMLCERTIFICATEDETAILSRESPONSE']._serialized_end=25779
  _globals['_GETCONNECTIONTESTRESULTREQUEST']._serialized_start=25782
  _globals['_GETCONNECTIONTESTRESULTREQUEST']._serialized_end=25916
  _globals['_GETCONNECTIONTESTRESULTRESPONSE']._serialized_start=25919
  _globals['_GETCONNECTIONTESTRESULTRESPONSE']._serialized_end=26236
  _globals['_PASSWORDCONNECTIONCONFIG']._serialized_start=26238
  _globals['_PASSWORDCONNECTIONCONFIG']._serialized_end=26264
  _globals['_FLAGS']._serialized_start=26266
  _globals['_FLAGS']._serialized_end=26323
  _globals['_LISTAPPCONNECTIONSREQUEST']._serialized_start=26326
  _globals['_LISTAPPCONNECTIONSREQUEST']._serialized_end=26752
  _globals['_LISTAPPCONNECTIONSRESPONSE']._serialized_start=26755
  _globals['_LISTAPPCONNECTIONSRESPONSE']._serialized_end=27245
  _globals['_CONNECTIONSERVICE']._serialized_start=28665
  _globals['_CONNECTIONSERVICE']._serialized_end=41985
# @@protoc_insertion_point(module_scope)
